function [T,Xin] = time_delay2(T,Xin,N,Ts)
%TIME_DELAY2 Create time delay vectors
%   Fixed version of time_delay.  Here size(Xin,2) is N.  In time_delay.m
%   size(Xin,2) = N-1.
%
%   [T,Xin] = time_delay2(T,Xin,N)
% 
%   Example: If N   = 4, 
%               Xin = [Xin(4:end-1,:) Xin(3:end-2,:) Xin(2:end-3,:) Xin(1:end-4,:)];
%               T   = T(5:end,:);
%   Note that the first column in Xin is closest to T in time.
%
%   Example:
%   [T,X]           = time_delay2([1:10]',[1:10]',5);[T,X]
% 
%   Other use:
%   [T,Xin] = time_delay2(T,Xin,N,Ts) (Ts>=0)
%
%   Example: If N   = 2, and 
%               Ts  = 2, then 
%               Xin = [Xin(2:end-3,:) Xin(1:end-4,:)];
%               T   = T(5:end,:);
%
%   Example:
%   [T,X]           = time_delay2([1:10]',[1:10]',5,2);[T,X]
%
%   See also TIME_DELAY

if (nargin < 4)  
  Ts = 0;
end

temp = [];
% for i = 1:N-1 old version
for i = 1:N
  temp = [Xin(i:end-(Ts+N-i+1),:) temp];
end  

Xin = temp; 
T   = T(N+1+Ts:end,:);

