function pre_arx(FILENAME1,FILENAME2)
% Prepares input files for run_arx
  
CISM_DX_GLOBALS; % Load global variables

fprintf('Program pre_arx.m is preparing input files ...\n');fflush(stdout);

X1       = load(FILENAME1);  
LAST1    = datenum(X1(end,1),X1(end,2),X1(end,3));
FIRST1   = datenum(X1(1,1),X1(1,2),X1(1,3));
DAYNUMS2 = datenum(X1(:,1),X1(:,2),X1(:,3));
if (max(diff(DAYNUMS2)>1))
  fprintf('    Time gap in input data set %s.',FILENAME1);
  error('Aborting\n.')
end

X2       = load(FILENAME2);  
LAST2    = datenum(X2(end,1),X2(end,2),X2(end,3));
FIRST2   = datenum(X2(1,1),X2(1,2),X2(1,3));
DAYNUMS2 = datenum(X2(:,1),X2(:,2),X2(:,3));
if (max(diff(DAYNUMS2)>1))
  fprintf('    Time gap in input data set %s.',FILENAME2);
  error('Aborting\n.')
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Should be using time union here.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Make inputs have same end date.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
DELTA = LAST2-LAST1;
if (DELTA > 0)
  LAST = LAST1;
  L    = size(X2,1)-DELTA;
  X2   = X2(1:L,:);
end
if (DELTA < 0)
  LAST = LAST2;
  L    = size(X1,1)+DELTA;
  X1   = X1(1:L,:);
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Make inputs have same start date.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
DELTA = FIRST2-FIRST1;
if (DELTA > 0)
  FIRST = FIRST2;
  L     = size(X1,1);
  X1    = X1(DELTA+1:L,:);
end
if (DELTA < 0)
  FIRST = FIRST1;
  L     = size(X2,1);
  X2    = X2(-DELTA+1:L,:);
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

X = [X1 X2(:,7)];

TODAY = floor(now);
LAST  = datenum(X(end,1),X(end,2),X(end,3));

if (TODAY-LAST == 0)
  fprintf('   (Last real time data available today.)\n',TODAY-LAST);fflush(stdout);
end
if (TODAY-LAST > 1)
  fprintf('   (Last real time data available %d day(s) ago.)\n',TODAY-LAST);fflush(stdout);
end


for i = 1:7
  x1    = [ymd(LAST+i),23,59,59,99999,99999];
  X     = [X ; x1];
end

% Write input file with timestamp
fid = fopen('T_full.dat','w');
for i = 1:size(X,1)
  fprintf(fid,'%4d %2d %2d %2d %2d %2d %8.2f\n',X(i,1:7));
end
fclose(fid);

% Write input file with timestamp
fid = fopen('X_full.dat','w');
for i = 1:size(X,1)
  fprintf(fid,'%4d %2d %2d %2d %2d %2d %8.2f %8.2f\n',X(i,:));
end
fclose(fid);

% Write input file for arx.c
fid = fopen('X.dat','w');
fprintf(fid,'%8.2f %8.2f\n',X(:,7:8)');
fclose(fid);

fprintf('... done preparing input files.\n');fflush(stdout);
