pro readmtsu, ts, m, n,name,nskip,sampl, $
	single_prec = single_prec, $
	print_path = print_path

; typical values are:   nskip=0,    sampl=1

; Reads in a *vector* (M-Dimensional) time series TS of length N at sampling 
; rate SAMPL.
; TS should be in an unformatted file of name NAME.
; It first skips NSKIP*NSAMPL elements, reads the following N*SAMPL elements
; and then collects every SAMPL-th of them
; 1. Disadvantage: needs (N-1)*SAMPL additional storage space
; 2. Assumption: the data are arranged in a long array: 1 record = 1 word
; 3. The array containing the corresponding observation time values is:
; 	t  = sampl*tscale*(findgen(n)+nskip+1)


; default parameters
if n_elements(single_prec) eq 0 then begin
	suffix = strmid(name, strlen(name)-2, 2)
	if suffix eq 'ud' then begin
		single_prec = 0 
	endif else begin
		single_prec = 1
	endelse
endif
if n_elements(print_path) eq 0 then print_path = 0


; define variables
if single_prec eq 1 then ts = fltarr(m, n) else ts = dblarr(m, n)


; announce reading
if print_path eq 1 then print, 'READTSU: Reading data from ', name


; skip NSKIP points
openr, 111, name
if nskip ne 0 then begin
	if single_prec eq 1 then tskip = fltarr(m, nskip*sampl) else tskip = dblarr(m, nskip*sampl)
	readu, 111, tskip
endif


; read data (depending on sampling rate SAMPL)
if sampl ne 1 then begin
	if single_prec eq 1 then longts = fltarr(m, n*sampl) else longts = dblarr(m, n*sampl)
	readu, 111, longts
	if single_prec eq 1 then aux = sampl*findgen(n) else aux = sampl*dindgen(n)
	ts = longts(aux)
endif else readu, 111, ts
close, 111


return
end
