function plot_output()
%PLOT_OUTPUT Plots model output

CISM_DX_GLOBALS; % Load global variables
  
fprintf('Program plot_output.m is plotting data to eps file ...\n');fflush(stdout);  


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Set some local variables
NDAYS         = 30;
LEAD_TIME     = 0;
threat(1)     = 0.8;
threat(2)     = 0.9;
MINY          = 1;
MINX          = 0;
MAXY          = 10;
YSTEP         = 1;
Nright        = 4;
MAXX          = NDAYS+LEAD_TIME+Nright;
EPS_NAME      = './web_page/je_current.eps';

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Get ensemble prediction
Xf = load('./je_fir_0.1/T_full.dat');
% Replace negative values with zero.
temp               = Xf(:,7:size(Xf,2));
I                  = find(temp < 0);
temp(I)            = 0;
Xf(:,7:size(Xf,2)) = temp;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
DAY_F         = datenum(Xf(end,1),Xf(end,2),Xf(end,3))-LEAD_TIME-1;
DAY_I         = DAY_F-NDAYS;
DAYS_AVAIL_Xf = datenum(Xf(:,1),Xf(:,2),Xf(:,3));
DAYS_PLOT     = [DAY_I+1:DAY_F+LEAD_TIME+Nright];
DAYS_LABEL    = [floor(now):-7:DAY_I];
DAYS_LABEL    = [DAYS_LABEL,[floor(now):7:DAY_F+LEAD_TIME+3]];

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Looks for days to plot that forecast data is available.
for i = 1:length(DAYS_PLOT)
  for j = 7:size(Xf,2)
    I = find(DAYS_AVAIL_Xf == DAYS_PLOT(i)); 
    if (~isempty(I))
      NODATA(i)  = 0;
      Vf(i,j-6)  = mean(Xf(I,j));  
      Date(i,:)  = Xf(I(end),1:6);
    else
      NODATA(i)  = 1;
      Vf(i,j-6)  = CISM_DX_FLAG;
      temp       = datestr(DAYS_PLOT(i),29);
      Date(i,:)  = [ymd(DAYS_PLOT(i)),0,1,1];
    end
    YLabels(j-6,:) = (j-7);
  end
  Vplot(i,:) = Vf(i,:);
end

% Looks for days to plot that actual data is available.
for i = 1:length(DAYS_PLOT)
  I = find(DAYS_PLOT(i) == DAYS_LABEL);
  if (isempty(I))
      XLabels(i,:) = '        ';  
  else
      XLabels(i,:) = datestr(datenum(Date(i,1),Date(i,2),Date(i,3)),2);
%   if (DAYS_PLOT(i) == DAYS_LABEL(end))
%     XLabels(i,:) = datestr(datenum(Date(i,1),Date(i,2),Date(i,3)),2);
%   end
  end
end

%XLabels = [XLabels ; repmat('        ', Nright,1)];
%Vplot   = [Vplot   ; repmat(CISM_DX_FLAG,Nright,size(Vplot,2))];

% Replace CISM_DX_FLAG values with zero.
I = find(Vplot == CISM_DX_FLAG); Vplot(I) = 0;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

eglobpar2;   % get access to global parameters
einit2;

eWinWidth   = 195.9; % mm
eWinHeight  = 130;

eopen2(EPS_NAME);

eImageLegendLabelText = '';
esavpar2;    % save default parameter

% set tics
eAxesValueSpace      = 3;
eAxesTicLongLength   = -1;
eAxesTicShortLength  = 0;

erespar2; % set default parameter

% Plot Gray strip
ePlotAreaPos         = [20 28];
ePlotAreaWidth       = 150;
L  = size(Vplot,1);
xi = 0.5+L-LEAD_TIME-27-Nright;
xf = 0.5+L-LEAD_TIME-Nright;
xb = [xi xi xf xf];
yb = [0 3 3 0];
eXAxisNorthVisible   = 0;
eYAxisEastVisible    = 0;
eXAxisSouthVisible   = 0;
eYAxisWestVisible    = 0;

eAxes2([0 1 MAXX],XLabels,[MINY YSTEP MAXY],YLabels);
eplot2(xb,yb,'',-1,[0.75 0.75 0.75]);
eplot2;

ePlotAreaPos         = [20 40];
ePlotAreaWidth       = 150;
ePlotAreaHeight      = 80;
eYAxisWestLabelText  = 'L-Shell [R_E]';
eXAxisSouthLabelText = '';
eImageLegendPos      = [0 -1];
ePlotLegendPos       = [-10 -20];
ePlotTitleDistance   = 5;
ePlotTitleFontSize   = 4;
ePlotTitleText       = 'Prediction of SAMPEX MeV Electron Flux';
eXAxisSouthVisible   = 1;
eYAxisWestVisible    = 1;
eXAxisNorthVisible   = 0;
eYAxisEastVisible    = 0;
eYAxisWestLabelDistance = 2;

% Add legend line for an invisible line
xi = 0.5;
xf = 0.5;
xb = [xi xi xf xf];
yb = [0 0 0 0];
eplot2(xb,yb,'High MeV Electron Flux',-1,[1 0 0])

% Add legend line for an invisible line
xi = 0.5;
xf = 0.5;
xb = [xi xi xf xf];
yb = [0 0 0 0];
eplot2(xb,yb,'Moderate MeV Electron Flux',-1,[1 1 0])

% Plot gray strip
L  = size(Vplot,1);
xi = 0.5+L-LEAD_TIME-1-27;
xf = 0.5+L-LEAD_TIME-1;
xb = [xi xi xf xf];
yb = [0 1 1 0];
eplot2(xb,yb,'27 days of most recent solar rotation',-1,[0.7 0.7 0.7])

% Add legend line for an invisible line
xi = 0.5;
xf = 0.5;
xb = [xi xi xf xf];
yb = [0 0 0 0];
eplot2(xb,yb,'Note that real-time measured data is not available',-1,[1 1 1]);

eAxes2([0 1 MAXX],XLabels,[MINY YSTEP MAXY],YLabels);

% Plot white where no data
if (1)
%if (~isempty(NODATA));
 if (isempty(NODATA));
  xm = min(find(NODATA==1))-1;
  xb = [xm xm  MAXX MAXX];
  yb = [MINY MAXY MAXY  MINY];
  eplot2(xb,yb,'',-1,[1 1 1])
 end
end

xData = [0 10 10 0];
yData = [0 0 10 10];
color = [0 1 0];

ePlotAreaXFac = ...
    ePlotAreaWidth*eFac/(ePlotAreaXValueEnd-ePlotAreaXValueStart);
ePlotAreaYFac = ...
    ePlotAreaHeight*eFac/(ePlotAreaYValueEnd-ePlotAreaYValueStart);

xData = (xData-ePlotAreaXValueStart)*ePlotAreaXFac;
yData = (yData-ePlotAreaYValueStart)*ePlotAreaYFac;

%exyplotf2(EPS_NAME,ePlotAreaPos(1)*eFac,ePlotAreaPos(2)*eFac,...
%	 xData(1,:),yData(1,:),color)

% Plot right plot box line
eplot2([MAXX MAXX],[MINY MAXY],'',0,[0 0 0]);
% Plot top plot box line
eplot2([MINX MAXX],[MAXY MAXY],'',0,[0 0 0]);

colorMap = [0 1 0;0 0 0;0 0 1;1 1 0;1 0 0];

eimagesc_2d(Vplot',colorMap,'e',[0 0.5 5],XLabels); % print scaled image

eplot2;

x1   = MAXX;
y1   = MAXY+0.5;
xpos = eFac*ePlotAreaPos(1)+(x1-ePlotAreaXValueStart)*ePlotAreaXFac;
ypos = eFac*ePlotAreaPos(2)+(y1-ePlotAreaYValueStart)*ePlotAreaYFac;
etext2('Log(Je)',xpos,ypos,4,1)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

eplot2; % Close the axis
eclose2; % Close the file

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
fprintf('... done plotting data.\n');fflush(stdout);
