%function plot_output()
%PLOT_OUTPUT Plots model output
  
% RSW 04/15/2004.  
  
fprintf('Program plot_output.m is plotting data to eps file ...\n');
fflush(stdout);  
CISM_DX_GLOBALS; % Load global variables  

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Set some local variables
NDAYS       = 40;               % Number of days to plot		      
LEAD_TIME   = 7;		% Max lead time			      
threat(1)   = 600;		% Low threat level on plot		      
threat(2)   = 800;		% High threat level on plot		      
MINY        = 0;		% Min y-value on plot			      
MINX        = 0;		% Min x-value on plot			      
MAXY        = 1000;		% Max y-value on plot			      
YSTEP       = 200;		% Horizontal grid spacing in y-direction     
Nright      = 3;
MAXX        = NDAYS+LEAD_TIME;	% Number of days to the right to leave empty.
NAME        = 'Vsw';
UNITS       = '[km/sec]';
EPS_NAME    = sprintf('./web_page/%s_current.eps',NAME);
NOTE_HIGH   = '';
NOTE_MEDIUM = '';
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Get ensemble prediction
T_full       = load('./Persistence/T_full.dat');

clear ensemble_prediction;
T_ensemble   = ensemble_prediction;
L            = size(T_full,1);   % Number of rows
Xa           = T_full;           % a = actual ('full' means with time stamp)
Xf           = T_ensemble;       % f = forecasted
Xf           = unique(Xf,'rows');% Remove duplicate rows
Xa           = unique(Xa,'rows');% Remove duplicate rows
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Dump last 10 data points to screen
fprintf('Last 10 data points of forecast:\n');
temp         = Xf;
Lw           = size(Xf,2);
temp(:,7:Lw) = floor(temp(:,7:Lw)); % (So integer formatting of listing)
fprintf('%4d %2d %2d %2d %2d %2d %5d %5d %5d %5d %5d %5d %5d\n',...
	temp(size(Xf,1)-9:size(Xf,1),:)')
fprintf('Last 10 data points of measured:\n');
temp         = Xa;
Lw           = size(Xa,2);
temp(:,7:Lw) = floor(temp(:,7:Lw)); % (So integer formatting of listing)
fprintf('%4d %2d %2d %2d %2d %2d %5d\n',temp(size(Xa,1)-9:size(Xa,1),:)')
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Looks for days to plot that forecast data is available.

if (0)
[Vf,Va,T]  = time_union(Xf,Xa,CISM_DX_FLAG,'day');
L          = length(Va);

Days       = day_number(T);
I          = find(Days == floor(now));
XLabels    = date_labels([1:L]',[1:7:L]',T(1,:));

Iplot      = [I-NDAYS+1:I+LEAD_TIME];
XLabels    = XLabels(Iplot,:);
end

if (1)
DAY_F         = datenum(Xa(end,1),Xa(end,2),Xa(end,3))-LEAD_TIME-1;
DAY_I         = DAY_F-NDAYS;
DAYS_AVAIL_Xf = datenum(Xf(:,1),Xf(:,2),Xf(:,3)); % Available days of forecast
DAYS_AVAIL_Xa = datenum(Xa(:,1),Xa(:,2),Xa(:,3)); % Available days of forecast
DAYS_PLOT     = [DAY_I+1:DAY_F+LEAD_TIME+1];      % What days to plot
DAYS_LABEL    = [floor(now):-7:DAY_I];            % Label every seven days
DAYS_LABEL    = [DAYS_LABEL,[floor(now):7:DAY_F+LEAD_TIME+1]];

% Looks for days to plot that forecast data is available.
for i = 1:length(DAYS_PLOT)
  I = find(DAYS_AVAIL_Xf == DAYS_PLOT(i));
    if (~isempty(I))
      Vf(i,1:LEAD_TIME) = Xf(I,7:7+LEAD_TIME-1);
      Date(i,:)         = Xf(I(end),1:6);
    else
      Vf(i,1:LEAD_TIME) = CISM_DX_FLAG;
      temp              = datestr(DAYS_PLOT(i),29);
      Date(i,:)         = [str2num(temp(1:4)),str2num(temp(5:6)),...
                           str2num(temp(7:8)),0,1,1];
    end
end

% Looks for days to plot that actual data is available.
for i = 1:length(DAYS_PLOT)
  I = find(DAYS_AVAIL_Xa == DAYS_PLOT(i));
    if ~isempty(I)
      Va(i,1)           = Xa(I,7);
      Date(i,:)         = Xa(I,1:6);
    else
      Va(i,1)           = CISM_DX_FLAG;
      temp              = datestr(DAYS_PLOT(i),29);
      Date(i,:)         = [str2num(temp(1:4)),str2num(temp(5:6)),...
                           str2num(temp(7:8)),0,1,1];
    end
end
% Form labels for x-axis
for i = 1:length(DAYS_PLOT)
  I = find(DAYS_PLOT(i) == DAYS_LABEL);
  if (isempty(I))
      XLabels(i,:) = '        ';
  else
      XLabels(i,:) = datestr(datenum(Date(i,1),Date(i,2),Date(i,3)),2);
    if (DAYS_PLOT(i) == DAYS_LABEL(end))
      XLabels(i,:) = datestr(datenum(Date(i,1),Date(i,2),Date(i,3)),2);
    end
  end
end
XLabels = [XLabels ; repmat('        ',Nright,1)];
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Create eps plots using epsTK
eglobpar2;        % get access to global parameters
einit2;

eWinWidth   = 195.9; % mm
eWinHeight  = 130;


eopen2(EPS_NAME); % open eps-file and write eps-head

eWinWidth      = 140;
eWinHeight     = 100;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Plot Gray strip
ePlotAreaPos         = [20 28];
ePlotAreaWidth       = 150;
ePlotAreaHeight      = 80;
L  = size(Va,1);
xi = 0.5+L-LEAD_TIME-27-1;
xf = 0.5+L-LEAD_TIME-1;
xb = [xi xi xf xf];
yb = [0 200 200 0];
eXAxisNorthVisible   = 0;
eYAxisEastVisible    = 0;
eXAxisSouthVisible   = 0;
eYAxisWestVisible    = 0;

eAxes2([MINX 1 MAXX],XLabels,[MINY YSTEP MAXY],[]);
eplot2(xb,yb,'27 days of most recent solar rotation',-1,[0.75 0.75 0.75]);
eplot2;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

eXAxisSouthVisible   = 1;
eYAxisWestVisible    = 1;

ePlotAreaPos    = [20 40];

% Set up the Axes
eAxes2([0 1 MAXX],XLabels,[MINY YSTEP MAXY],[]);

if (0)
% Plot red horizontal strip
xb = [MINX MINX  MAXX MAXX];
yb = [MINY MAXY MAXY  MINY];
eplot2(xb,yb,'',-1,[1 0 0])
eplot2(xb,yb,'',-1,[1 0 0])

% Plot yellow horizontal strip
xb = [MINX MINX MAXX MAXX];
yb = [MINY threat(2) threat(2) MINY];
eplot2(xb,yb,'',-1,[1 1 0])

% Plot white horizontal strip
xb = [MINX MINX MAXX MAXX];
yb = [MINY threat(1) threat(1) MINY];
eplot2(xb,yb,'',-1,[1 1 1])
end

if (0)
L = size(Va,1);

% Plot 27-day gray strip 
 xi = 0.5+L-LEAD_TIME-1-27;
 xf = 0.5+L-LEAD_TIME-1;
 xb = [xi xi xf xf];
 yb = [MINY threat(1) threat(1) MINY];
 eplot2(xb,yb,'27 days of most recent solar rotation',-1,[0.9 0.9 0.9])
end

if (0)
% Plot 27-day gray strip 
xi = 0.5+length(Iplot)-LEAD_TIME-1-27;
xf = 0.5+length(Iplot)-LEAD_TIME-1;
xb = [xi xi xf xf];
yb = [MINY threat(1) threat(1) MINY];
eplot2(xb,yb,'27 days of most recent solar rotation',-1,[0.9 0.9 0.9])
end

% Plot horizontal grid lines
%for i = 0:YSTEP:MAXY
%  yh      = [i i];
%  xh      = [MINX MAXX];
%  eplot2(xh,yh,'',0,[0 0 0]);
%end

% Plot right bounding line
eplot2([MAXX MAXX],[MINY MAXY],'',0,[0 0 0]);

% Plot top bounding line
eplot2([MINX MAXX],[MAXY MAXY],'',0,[0 0 0]);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Plot blue bars of actual measurements
I         = find(abs(Va)>=0.99*CISM_DX_FLAG); % Find flagged values
Va(I)     = -1;                       % Put off scale
%[xb yb]   = ebar2(Va(Iplot),1,1,1,0.5+[0:length(Iplot)-1]); 
[xb yb]   = ebar2(Va(1:L),1,1,1,0.5+[0:L-1]); 
eplot2(xb,yb,sprintf('Measured %s',NAME),-1,[0 0 1])
% Plot black outline around bars
eplot2(xb,yb,'',0,[0 0 0]) 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Plot black bars of 1-day prediction
I         = find(abs(Vf(:,1))>=0.99*CISM_DX_FLAG); % Find flagged values
Vf(I,1)   = -1;                            % Put off scale
%[xb yb]   = ebar2(Vf(Iplot,1),0.5,1,1,0.5+[0:length(Iplot)-1]); 
[xb yb]   = ebar2(Vf(1:L,1),0.5,1,1,0.5+[0:L-1]); 

eplot2(xb,yb,sprintf('Predicted %s',NAME),-1,[0 0 0])
eplot2(xb,yb,'',0,[0 0 0]);                % Plot black outline around bars
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Plot black predition bars for 2-day to LEAD_TIME-day predictions
for i = 1:LEAD_TIME
%  I         = find(abs(Vf(:,i))>=0.99*CISM_DX_FLAG); % Find flagged values
%  if (~isempty(I))
%    Vf(I,i)   = -1;                          % Put off scale
%  end
%  a         = length(Iplot)-LEAD_TIME-1+i;
%  Ip        = Iplot(a);
 I        = [L-LEAD_TIME+i-1];
 if (abs(Vf(I,i))>CISM_DX_FLAG*0.99)
   Vf(I,i)= -1;
 end
 [xb yb]   = ebar2(Vf(I,i),0.5,1,1,-0.5+I); 

  eplot2(xb,yb,'',-1,[0 0 0])
  eplot2(xb,yb,'',0,[0 0 0]);  % Plot black outline around bars
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

eplot2; % Close the current plot

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Compute probabilities
Tf = L-LEAD_TIME;
I1 = find(Va > threat(1) & abs(Va) < CISM_DX_FLAG & Vf(:,1) > 0.9*Vf(Tf,1)  & Vf(:,1) < 1.1*Vf(Tf,1));
I2 = find(Va > threat(2) & abs(Va) < CISM_DX_FLAG &  Vf(:,1) > 0.9*Vf(Tf,1) & Vf(:,1) < 1.1*Vf(Tf,1));

if (~isempty(I1))
  L  = find(abs(Va) < CISM_DX_FLAG);
  p1 = length(I)/length(L);
else
  p1 = 0;
end
if (~isempty(I2))
  L  = find(abs(Va) < CISM_DX_FLAG);
  p2 = length(I)/length(L);
else
  p2 = 0;
end

str1 = sprintf('Probability of %s > %2d is %.2f for %s',NAME,threat(1),p1,date);
str2 = sprintf('Probability of %s > %2d is %.2f for %s',NAME,threat(2),p2,date);
eplotlg2(eFile,250,50,[1 1 1],0,0,str1,eFonts(ePlotLegendTextFont,:),10);
eplotlg2(eFile,250,60,[1 1 1],0,0,str2,eFonts(ePlotLegendTextFont,:),10);

% Add text for probability
%x1   = xf+0;
%y1   = threat(2)-2.0;
%xpos = ePlotAreaPos(1)+(x1-ePlotAreaXValueStart)*ePlotAreaXFac/eFac;
%ypos = ePlotAreaPos(2)+(y1-ePlotAreaYValueStart)*ePlotAreaYFac/eFac;
%etext2('x',xpos,ypos,4,0)

% Add text for probability
%x1   = xf+0;
%y1   = threat(1)-3.5;
%xpos = ePlotAreaPos(1)+(x1-ePlotAreaXValueStart)*ePlotAreaXFac/eFac;
%ypos = ePlotAreaPos(2)+(y1-ePlotAreaYValueStart)*ePlotAreaYFac/eFac;
%etext2('*',xpos,ypos,4,0)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if (0)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Plot note on red bar
x1   = 1;
y1   = (threat(2)+MAXY)*0.5;
xpos = ePlotAreaPos(1)+(x1-ePlotAreaXValueStart)*ePlotAreaXFac/eFac;
ypos = ePlotAreaPos(2)+(y1-ePlotAreaYValueStart)*ePlotAreaYFac/eFac;
etext2(NOTE_HIGH,xpos,ypos,3,1)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Plot note on yellow bar
x1   = 1;
y1   = (threat(1)+threat(2))*0.5;
xpos = ePlotAreaPos(1)+(x1-ePlotAreaXValueStart)*ePlotAreaXFac/eFac;
ypos = ePlotAreaPos(2)+(y1-ePlotAreaYValueStart)*ePlotAreaYFac/eFac;
etext2(NOTE_MEDIUM,xpos,ypos,3,1)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Plot vertical grey bars
yh      = [threat(1) MAXY];
xh      = [(xf-0.5) (xf-0.5)];
eplot2(xh,yh,'',0,[0.5 0.5 0.5]);
yh      = [threat(1) MAXY];
xh      = [(xf+0.5) (xf+0.5)];
eplot2(xh,yh,'',0,[0.5 0.5 0.5]);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
end
eplot2; % Close the axis
eclose2; % Close the file

fprintf('Done plotting data.\n');fflush(stdout);  

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
