%%NAME
%%  eAxes - draw scaled Axes around plot area
%%
%%SYNOPSIS
%%  eAxes ([xAxisSouthScale,yAxisWestScale[,xAxisNorthScale,yAxisEastScale]])
%%
%%PARAMETER(S)
%%  xAxisSouthScale   scale vector of south axis [start step end]
%%  yAxisWestScale    scale vector of west axis  [start step end]
%%  xAxisNorthScale   scale vector of north axis [start step end]
%%  yAxisEastScale    scale vector of east axis  [start step end]
%%
%%    special cases of scale vectors are:
%%      if start=0 and end=0 then autorange=on 
%%      if step=0 then autoscale=on
%%    (default scale vector=[0 0 0])
%%
%%GLOBAL PARAMETER(S)
%%  eXAxis(South|West|East|North)ValueFormat
%%  eXAxis(South|West|East|North)ValueVisible
%%  eAxesValueFontSize
%%  eAxesValueSpace
%%  eAxesColor
%%  eAxesLineWidth
%%  eAxesTicShortLength
%%  eAxesTicLongLength
%%  eAxesTicLongMaxN
%%  eAxesCrossOrigin
%%  eAxesValueSpace
%%  eAxesLabelFontSize
%%  eAxesLabelTextFont
%%  eXAxis(South|West|East|North)Scale
%%  eXAxis(South|West|East|North)ScaleType
%%  eXAxis(South|West|East|North)Visible
%%  eXAxis(South|West|East|North)ValueFormat
%%  eXAxis(South|West|East|North)ValueVisible
%%  eXAxis(South|West|East|North)LabelText
%%  eXAxis(South|West|East|North)LabelDistance
%%  ePlotAreaXValueStart
%%  ePlotAreaXValueEnd
%%  ePlotAreaYValueStart
%%  ePlotAreaYValueEnd
%%  ePlotAreaPos
%%  ePlotAreaWidth
%%  ePlotAreaHeight
% written by Stefan Mueller stefan.mueller@fgan.de 1997

function eAxes(xAxisSouthScale,xAxisText,yAxisWestScale,yAxisText)
  eglobpar2;
  if nargin>0
    eXAxisSouthScale=xAxisSouthScale;
    ePlotAreaXValueStart=eXAxisSouthScale(1);
    ePlotAreaXValueEnd=eXAxisSouthScale(3);
    eYAxisWestScale=yAxisWestScale;
    ePlotAreaYValueStart=eYAxisWestScale(1);
    ePlotAreaYValueEnd=eYAxisWestScale(3);
    range=ePlotAreaXValueEnd-ePlotAreaXValueStart;
    if range==0
      range=1;
      ePlotAreaXValueEnd=ePlotAreaXValueStart+range;
    end
    ePlotAreaXFac=ePlotAreaWidth*eFac/range;
    range=ePlotAreaYValueEnd-ePlotAreaYValueStart;
    if range==0
      range=1;
      ePlotAreaYValueEnd=ePlotAreaYValueStart+range;
    end
    ePlotAreaYFac=ePlotAreaHeight*eFac/range;
  end
  if eXAxisSouthScale(1)~=eXAxisSouthScale(3)
    ePlotAreaXValueStart=eXAxisSouthScale(1);
    ePlotAreaXValueEnd=eXAxisSouthScale(3);
  end
  if eXAxisNorthScale(1)~=eXAxisNorthScale(3)
    eXAxisNorthValueStart=eXAxisNorthScale(1);
    eXAxisNorthValueEnd=eXAxisNorthScale(3);
  else
    eXAxisNorthValueStart=ePlotAreaXValueStart;
    eXAxisNorthValueEnd=ePlotAreaXValueEnd;
    eXAxisNorthScale=eXAxisSouthScale;
    eXAxisNorthScaleType=eXAxisSouthScaleType;
  end
  if eYAxisWestScale(1)~=eYAxisWestScale(3)
    ePlotAreaYValueStart=eYAxisWestScale(1);
    ePlotAreaYValueEnd=eYAxisWestScale(3);
  end
  if eYAxisEastScale(1)~=eYAxisEastScale(3)
    eYAxisEastValueStart=eYAxisEastScale(1);
    eYAxisEastValueEnd=eYAxisEastScale(3);
  else
    eYAxisEastValueStart=ePlotAreaYValueStart;
    eYAxisEastValueEnd=ePlotAreaYValueEnd;
    eYAxisEastScale=eYAxisWestScale;
    eYAxisEastScaleType=eYAxisWestScaleType;
  end
  if sign(ePlotAreaXValueStart*ePlotAreaXValueEnd)<0 &...
     sign(ePlotAreaYValueStart*ePlotAreaYValueEnd)<0 & eAxesCrossOrigin
    eXAxisSouthVisible=1;
    eYAxisWestVisible=1;
    eXAxisNorthVisible=0;
    eYAxisEastVisible=0;
    xAxisOffset=-ePlotAreaYValueStart*ePlotAreaYFac;   
    yAxisOffset=-ePlotAreaXValueStart*ePlotAreaXFac;   
  else
    xAxisOffset=0;
    yAxisOffset=0;
  end
  % scale and draw Axes
  if eXAxisSouthVisible
    if eXAxisSouthScaleType==0
      escalexy2(eFile,'s',...
            ePlotAreaPos(1)*eFac,...
            ePlotAreaPos(2)*eFac,...
            -xAxisOffset,0,...
            ePlotAreaWidth*eFac,...
            ePlotAreaXValueStart,...
            eXAxisSouthScale(2),...
            ePlotAreaXValueEnd,...
            eXAxisSouthValueFormat,...
            eXAxisSouthValueVisible,...
            eAxesValueFontSize*eFac,...
            eAxesLineWidth*eFac,...
            eAxesTicShortLength*eFac,...
            eAxesTicLongLength*eFac,...
            eAxesTicLongMaxN,...
            eAxesValueSpace*eFac,...
            eAxesColor,...
	    xAxisText,...
	    yAxisText);
    elseif eXAxisSouthScaleType==1
      escalecl(eFile,'s',...
            ePlotAreaPos(1)*eFac,...
            ePlotAreaPos(2)*eFac,...
            -xAxisOffset,0,...
            ePlotAreaWidth*eFac,...
            ePlotAreaXValueStart,...
            eXAxisSouthScale(2),...
            ePlotAreaXValueEnd,...
            eXAxisSouthValueFormat,...
            eXAxisSouthValueVisible,...
            eAxesValueFontSize*eFac,...
            eAxesLineWidth*eFac,...
            eAxesTicLongLength*eFac,...
            eAxesTicLongMaxN,...
            eAxesValueSpace*eFac,...
            eAxesColor);
    end
  end
  if eYAxisWestVisible
    if eYAxisWestScaleType==0
      escalexy2(eFile,'w',...
            ePlotAreaPos(1)*eFac,...
            ePlotAreaPos(2)*eFac,...
            -yAxisOffset,0,...
            ePlotAreaHeight*eFac,...
            ePlotAreaYValueStart,...
            eYAxisWestScale(2),...
            ePlotAreaYValueEnd,...
            eYAxisWestValueFormat,...
            eYAxisWestValueVisible,...
            eAxesValueFontSize*eFac,...
            eAxesLineWidth*eFac,...
            eAxesTicShortLength*eFac,...
            eAxesTicLongLength*eFac,...
            eAxesTicLongMaxN,...
            eAxesValueSpace*eFac,...
            eAxesColor,...
	    xAxisText,...
	    yAxisText);
    elseif eYAxisWestScaleType==1
      escalecl(eFile,'w',...
            ePlotAreaPos(1)*eFac,...
            ePlotAreaPos(2)*eFac,...
            -yAxisOffset,0,...
            ePlotAreaHeight*eFac,...
            ePlotAreaYValueStart,...
            eYAxisWestScale(2),...
            ePlotAreaYValueEnd,...
            eYAxisWestValueFormat,...
            eYAxisWestValueVisible,...
            eAxesValueFontSize*eFac,...
            eAxesLineWidth*eFac,...
            eAxesTicLongLength*eFac,...
            eAxesTicLongMaxN,...
            eAxesValueSpace*eFac,...
            eAxesColor);
    end
  end

  %print labels
  scaleSpace=eAxesTicLongLength+eAxesValueSpace+eAxesValueFontSize;
  if strcmp(eXAxisSouthLabelText,'')~=1
    etext2(eXAxisSouthLabelText,...
          ePlotAreaPos(1)+ePlotAreaWidth/2,...
          ePlotAreaPos(2)-scaleSpace-...
          eAxesLabelFontSize*0.72-eXAxisSouthLabelDistance,...
          eAxesLabelFontSize,0,eAxesLabelTextFont,0);
  end
  if strcmp(eYAxisWestLabelText,'')~=1
    etext2(eYAxisWestLabelText,...
          ePlotAreaPos(1)-scaleSpace-eYAxisWestLabelDistance,...
          ePlotAreaPos(2)+ePlotAreaHeight/2,...
          eAxesLabelFontSize,0,eAxesLabelTextFont,90);
  end
