#!/usr/bin/perl
#
# This script is used to verify whether or not two images differ for
# OpenDX unit testing.
#
# This script requires that ImageMagick is installed.  (specifically,
# it uses the 'convert' and 'compare' command-line utilities)
#
#  Time-stamp: <2007-12-03 11:18:44 schmitt>
#  Peter Schmitt [schmitt(at)ucar.edu]
#############################################################################

use File::Temp qw/ tempfile tempdir /;

#############################################################################

$ARGC=scalar(@ARGV); 

if ($ARGC != 1 ){
    print "USAGE: \n";
    print "  ./verify_images.pl \"test name\"\n";
    print "  Verifies the test image rendered for \"test name\"\n";
    exit();
}

print "Running test for " . $ARGV[0];

$base_image = "images/" . $ARGV[0] . "_base.tiff";
$test_image = "images/" . $ARGV[0] . "_test.tiff";

# setup base case
($fh, $base_diff) = tempfile( $template, SUFFIX => '.tiff');
$call = "convert " . $base_image." ".$base_image." -compose difference -composite -colorspace gray ".$base_diff;
$output=`$call`;

# setup test case
($fh, $test_diff) = tempfile( $template, SUFFIX => '.tiff');
$call = "convert " . $base_image." ".$test_image." -compose difference -composite -colorspace gray ".$test_diff;
$output=`$call`;

# Compare the base & test cases:
# MAE = Mean Absolute Error
# for other metrics, see documentation at [http://www.imagemagick.org/Usage/compare/].
$call = "compare -metric MAE " . $base_diff . " " . $test_diff . " null:";
$output = `$call`;

# For identical images, "output" should look like:
#    0 dB
#    1152,1152,JPEG

# For differing images, "output" should look like:
#    17455.5 dB
#    1152,1152,JPEG

($val, $db, $info) = split " ",$output;
#print $val, "\n";
#print $db, "\n";
#print $info, "\n";


if ( length($output) <= 1 ) {
    print "... FAILED!\n";
    print "ImageMagick \"compare\" function did not execute properly.\n";
    print "Make sure you have an up-to-date version of ImageMagick installed\n";
    exit(1);
}

if ($val > 1) {
    `cp $test_diff images/$ARGV[0]_FAILED.tiff`;
    print "... FAILED!\n";
    print "ImageMagick \"compare\" output:\n";
    print "   $val $db \n   $info\n";
    print "ERRROR:  Images differ for test $ARGV[0]\n";
    exit(1);
}

print "... Passed!\n";
