%%NAME
%%  eopen2  - open EPS-file, define size of page, size of window and
%%           call 'einit' to initialize the global parameter
%%
%%SYNOPSIS
%%  eopen2([ epsFileName[,pageOrientation[,winWidth,winHeight
%%        [,origin[,xScaleFac,yScaleFac[,pageWidth,pageHeight]]]]]])
%%
%%PARAMETER(S)
%%  epsFileName       name of eps-file (default name is defined as eFileName)
%%  pageOrientation   page orientation,
%%                    0=portrait 1=landscape 2=upside-down 3=seaside
%%  winWidth          width of window(=eps bounding-box)
%%  winHeight         height of window(=eps bounding-box)
%%  origin            vector of origin, [xOffset yOffset]
%%  xScaleFac         scale factor 1= no resize   
%%  yScaleFac         scale factor 1= no resize   
%%  pageWidth         width of page
%%  pageHeight        height of page
%% 
%%GLOBAL PARAMETER(S)
%%  eFileName
%%  ePageWidth
%%  ePageHeight
%%  ePageScaleFac
%%  ePageOrientation
%%  eUserUnit
%%  eWinWidth
%%  eWinHeight
%%  eWinOrigin
%%  eFonts
% written by Stefan Mueller stefan.mueller@fgan.de 1997

function eopen2(epsFileName,pageOrientation,winWidth,winHeight,origin,xScaleFac,yScaleFac,pageWidth,pageHeight)
  if nargin>9 | nargin==3 | nargin==6 | nargin==8
    usage ('eopen2 ( [ epsFileName[,pageOrientation,[winWidth,winHeight[,origin[,xScaleFac,yScaleFac[,pageWidth,pageHeight]]]]] )');
  end

  eglobpar2;

  %fprintf('eopen2: eWinHeight=%d\n',eWinHeight);
  %fprintf('eopen2: eWinWidth=%d\n',eWinWidth);
  %ePageHeight
  %einit2;

  ePlotLineNr=0;
  ePolarPlotLineNr=0;
  eXScaleFac=1;
  eYScaleFac=1;

  if nargin>0
    eFileName=epsFileName;
  end
  if all(eFileName(1) ~= './')
     % eFileName = [getenv('TMPDIR') , '/' , eFileName ];
     eFileName = [getenv('TMPDIR') , './' , eFileName ];  
  end
  if nargin>1
    ePageOrientation=pageOrientation;
  end
  if nargin==2 & rem(ePageOrientation,2)
    winW=eWinWidth;
    eWinWidth=eWinHeight;
    eWinHeight=winW;
  end
  if nargin>3
    eWinWidth=winWidth;
    eWinHeight=winHeight;
  end
  if nargin>4
    eWinOrigin=origin;
  end
  if nargin>5
    eXScaleFac=xScaleFac;
    eYScaleFac=yScaleFac;
  end
  if nargin>7
    ePageWidth=pageWidth;
    ePageHeight=pageHeight;
  end
  
  % open eps file
  eFile=fopen(eFileName,'w');
  if eFile<0
    errortext=sprintf('     error in eopen2: can not open %s',eFileName);
    disp(errortext);
  else 

    % set user units
    if strcmp(eUserUnit,'mm')
      eFac=2.834646;
    elseif strcmp(eUserUnit,'cm')
      eFac=28.34646;
    elseif strcmp(eUserUnit,'inch')
      eFac=72;
    else 
      eFac=1;
    end

    % write eps head
    ehead2(eFile,eWinWidth*eFac,eWinHeight*eFac,...
          ePageWidth*eFac,ePageHeight*eFac,...
          ePageOrientation,eXScaleFac,eYScaleFac,...
          eWinOrigin(1)*eFac,eWinOrigin(2)*eFac);
  
    % reencode fonts
    newFonts=erencode2(eFile,eFonts(1,:));
    for i=2:size(eFonts,1)
      newFonts=[newFonts;erencode2(eFile,eFonts(i,:))];
    end
    eFonts=newFonts;
  end
