function esubplot2(R,C,n,scale_factor)
%ESUBPLOT2 Create uniformly sized sub-panels.
%
%   ESUBPLOT2(M,N,p) 
%
%   ESUBPLOT2(M,N,p,scale_factor) 
%
%   scale_factor = [sx,sy] allows one to manually shrink
%   contents of subplot by fractions sx and sy in the vertical
%   and horizontal directions, respectively.
%
%   See also ESUBPLOT2_DEMO.
  
% R.S. Weigel 07/07/2004.

if (nargin <  4)
  scale_factor = [1 1];
end
  
eglobpar2; % get access to global parameters

Hy = 5*ePlotTitleDistance + ...
     (ePlotTitleFontSize)*~isempty(ePlotTitleText) + ...
     (eAxesValueFontSize)*eXAxisSouthVisible + ...
     (eAxesLabelFontSize)*~isempty(eXAxisSouthLabelText) + ...
     (eAxesValueFontSize)*eXAxisNorthVisible + ...
     (eAxesLabelFontSize)*~isempty(eXAxisNorthLabelText);

Hx = (eAxesValueFontSize)*eYAxisEastVisible + ...
     (eAxesLabelFontSize)*~isempty(eYAxisEastLabelText) + ...
     (eAxesValueFontSize)*eYAxisWestVisible + ...
     (eAxesLabelFontSize)*~isempty(eYAxisWestLabelText);

Hx  = 2.0*Hx;
% A guess.  Need to compute width of AxesValues 
% to get an exact number.

Hx = Hx/scale_factor(1);
Hy = Hy/scale_factor(2);

ePlotAreaHeight = (eWinHeight-(R+0.5)*Hy)/R;
ePlotAreaWidth  = (eWinWidth-(C+0.5)*Hx)/C;

%ePlotAreaHeight = -Hy+(eWinHeight)/R
%ePlotAreaWidth  = -Hx+(eWinWidth)/C

N  = R*C;

I  = [R:-1:1];
Yo = (ePlotAreaHeight)*(I-1) + I*Hy;
Yo = repmat(Yo,C,1);
Yo = Yo(:);

I  = [1:C]';
Xo = (ePlotAreaWidth)*(I-1) + I*Hx;
Xo = repmat(Xo,1,R);
Xo = Xo(:);

ePlotAreaPos = [Xo(n) Yo(n)];

esavpar2;

  