function EEPCOLOR(Xc,Yc,Zc,P)
%EECONTOUR Easier ECONTOUR
%
%   EEPCOLOR(Z)
%   EEPCOLOR(Z,P)
%   EEPCOLOR(X,Y,Z) 
%   EEPCOLOR(Z,Y,Z,P) 
%
%   Sets plot parameters, where P is a strucutre with fields 
%   
%   P.FileName     = 'eepcolor0.eps';
%   P.Title        = [] ; 
%   P.XLimits      = [] ; A three element array, where xmin = Xlims(1), xmax =
%                         Xlims(3), and step = Xlims(2).
%   P.YLimits      = [] ; Same form as Xlims.
%   P.Legend       = '' ; Legend is a cell array.
%   P.LineColors   = [] ; A Nx3 matrix of rgb colors, where N is the
%                         number of lines.
%   P.LineWidths   = 0.5; A vector with N elements (see eplot width parameter)
%   P.DashLengths  = 0  ; A vector with N elements (see eplot dash parameter)
%   P.e*                ; Where e* is any of the global parameters 
%                         listed in the help for EPLOT, EOPEN, and EAXES.
%   P.NumColors    = 8  ; Number of colors in color bar.
%   P.ShowContours = 0  ; 
%   P.NumContours  = 8  ; Number of contour lines.
%   P.ContourLevels = [min(Z(:):dZc:max(Z(:)]; 
%                     dZc = (max(Z(:))-min(Z(:)))/NumContours
%
%   P.YAxisWestLabelEvery  = 1 ;  
%   P.XAxisSouthLabelEvery = 1 ;  
%   P.PlotPolar            = 0;  
%   P.PlotCartesian        = 1;  
%   P.MatrixView           = 0;  % If 1, plot as numbers look on screen.
%
%   See also EEPLOT.
  
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%  
if (nargin == 1)

  Zc = Xc; clear Xc;
  P.FileName = 'eepcolor0.eps';

  Xc = [1:size(Zc,1)];
  Yc = [1:size(Zc,2)];

end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%  

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%  
if (nargin == 2)

  if isstruct(Yc) 
    P  = Yc; clear Yc;
  else
    P.FileName = 'eepcolor0.eps';
  end

  Zc = Xc; clear Xc;
  Xc = [1:size(Zc,1)];
  Yc = [1:size(Zc,2)];

end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%  

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%  
if (nargin == 3)
  P.FileName = 'eepcolor0.eps';
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%  

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%  
if (~isfield(P,'FileName'))
  FileName = 'eepcolor0.eps';
else
  FileName = P.FileName;
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%  

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%  
if (~isfield(P,'FileName'))
  FileName = 'eepcolor0.eps';
else
  FileName = P.FileName;
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

eglobpar;         % get global parameters
einit;
eopen(FileName);  % open eps-file and write eps-head

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if (isfield(P,'eXAxisSouthLabelText'))
  eXAxisSouthLabelText = P.eXAxisSouthLabelText;
end
if (isfield(P,'eYAxisWestLabelText'))
  eYAxisWestLabelText = P.eYAxisWestLabelText;
end
if (isfield(P,'ePlotTitleText'))
  ePlotTitleText = P.ePlotTitleText;
end
if (isfield(P,'eImageLegendLabelText'))
  eImageLegendLabelText = P.eImageLegendLabelText;
end
if (isfield(P,'Title'));
  ePlotTitleText = P.Title;
end

eImageLegendLabelDistance=4; % mm
ePlotTitleFontSize=4;
ePlotTitleDistance=10;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%eWinGridVisible = 1;
%eWinFrameVisible= 1;

ePlotAreaHeight = 100;     % mm
ePlotAreaWidth  = 100;     % mm

eImageLegendPos = [0 -10];

if (~isfield(P,'XAxisSouthLabelEvery'))
  dlx = 1;
else
  dlx = P.XAxisSouthLabelEvery;  
end
if (~isfield(P,'YAxisWestLabelEvery'))
  dly = 1;
else
  dly = P.YAxisWestLabelEvery;  
end

if (~isfield(P,'ShowContours'))
  ShowContours=0;
else
  ShowContours=P.ShowContours; 
end

if (~isfield(P,'ShowContourValue'))
  eContourValueVisible=0;
else
  eContourValueVisible=P.ShowContourValue; 
end

if (~isfield(P,'NumContours'))
  NumContours = 8;
else
  NumContours = P.NumContours;
end

if (~isfield(P,'PlotPolar'))
  PlotPolar = 0;
else
  PlotPolar = P.PlotPolar;
end

if (~isfield(P,'PlotCartesian'))
  PlotCartesian = 1;
else
  PlotCartesian = P.PlotCartesian;
end

if (PlotCartesian & PlotPolar)
  PlotBoth = 1;
else
  PlotBoth = 0;
end


if (~isfield(P,'ContourLevels'))
  zo  = min(Zc(:));
  zf  = max(Zc(:));
  dZc = (zf-zo)/NumContours;
  ContourLevels = [zo dZc zf]; 
else
  ContourLevels = P.ContourLevels;
end

if (~isfield(P,'NumColors'))
  NumColors = 8;
else
  NumColors = P.NumColors;
end

if (~isfield(P,'eColorMapNo'))
  Cm = ecolors(0,NumColors);
else
  Cm = ecolors(P.eColorMapNo,NumColors);
end

if (size(Cm,1)>NumColors) & (eWarnColors == 1)
  warning(['eepcolor0: Number of requested colors (%d) is \n'...
	   ' too small for requested colormap (%d).  Changing NumColors'...
	   ' to %d'],NumColors,P.eColorMapNo,2*NumColors);
  Cm = ecolors(P.eColorMapNo,2*NumColors);
  NumColors = 2*NumColors;
end

if (~isfield(P,'eImageLegendScale'))
  eImageLegendScale = [0 0 0];
else
  eImageLegendScale = P.eImageLegendScale;
end

if (~isfield(P,'MatrixView'))
  plot_as_matrix = 0;
else
  plot_as_matrix = P.MatrixView;
end

if (isfield(P,'XLimits'))
  Xc = [P.XLimits(1):P.XLimits(2):P.XLimits(3)];
end  
if (isfield(P,'YLimits'))
  Yc = [P.YLimits(1):P.YLimits(2):P.YLimits(3)];
end
  
if (plot_as_matrix == 1)
  eXAxisSouthLabelText  = 'j';
  eYAxisWestLabelText   = 'i';
  eImageLegendLabelText = 'z(i,j)';
  if (nargin > 2) | isfield(P,'XLimits') | isfield(P,'YLimits')
    warning('Input X and Y limits or values are ignored when MatrixView=1');
  end
  Yc = [size(Zc,1):-1:1];
  Xc = [1:1:size(Zc,2)];
end

if (max(Zc(:))-min(Zc(:))==0)
%  fprintf('eepcolor0: Input matrix is constant.\n%s was not created.\n',...
%	  FileName)
%  return;
end

if ~isempty(find(isnan(Zc(:))==1))
  error('Input matrix contains one or more NaN values.');
end
if ~isempty(find(isinf(Zc(:))==1))
  error('Input matrix contains one or more Inf values.');
end


xmin  = Xc(1);
xstep = Xc(2)-Xc(1);
xmax  = Xc(end);

ymin  = Yc(1);
ystep = Yc(2)-Yc(1);
ymax  = Yc(end);

eXAxisSouthValueVisible=0; % no values visible
eXAxisNorthValueVisible=0; % no values visible
eYAxisEastValueVisible=0; % no values visible
eYAxisWestValueVisible=0; % no values visible
eImageLegendLabelPosition=1; 

if (~isfield(P,'eXAxisSouthScaleType'))
  eXAxisSouthScaleType = 1; % set classes scaling
else
  eXAxisSouthScaleType = P.eXAxisSouthScaleType;
end
if (~isfield(P,'eYAxisWestScaleType'))
  eYAxisWestScaleType = 1; % set classes scaling
else
  eYAxisWestScaleType = P.eYAxisWestScaleType;
end

xmin = xmin - xstep/2;
xmax = xmax + xstep/2;
ymin = ymin - ystep/2;
ymax = ymax + ystep/2;

if (max(Zc(:))==min(Zc(:)))
  Cm = [1 1 1 ; 1 1 1 ; 1 1 1]; % If constant matrix, fill with white.
end

if (0)
if (length(unique(Zc(:)))==2)
  c  = floor(size(Cm,1)/2);
  Cm = [Cm(1,:) ; Cm(c,:) ; Cm(end,:)]; % If only two unique values, use first,
					% last, and middle colors.
end
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if (PlotPolar == 1) 

ePolarPlotAreaCenterPos=[75,180];
ePolarPlotAreaRadMin=50*ymin/ymax;
ePolarPlotAreaRadMax=50;

ePolarAxisRadScale(1)=ymin;
ePolarAxisRadScale(2)=ystep;
ePolarAxisRadScale(3)=ymax;

if (plot_as_matrix == 0)
  epolaris(rot90(Zc),Cm,'e');
  if (ShowContours==1)
    econtourpol(rot90(Zc),ContourLevels,0,[1 1 1;0 0 0;0 0 0]);
  end
else
  epolaris(flipud(Zc),Cm,'e');
  if (ShowContours==1)
    econtourpol(flipud(Zc),ContourLevels,0,[1 1 1;0 0 0;0 0 0]);
  end
end

end % if (PlotPolar == 1)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if (PlotCartesian == 1) 

ePlotAreaPos = [25 20]; % x y position of left bottom corner of plot area
  
eaxes([xmin xstep xmax],[ymin ystep ymax])

if (max(abs(Xc-round(Xc)))==0)
  plot_x_as_int = 1;
else
  plot_x_as_int = 0;  
end

if (max(abs(Yc-round(Yc)))==0)
  plot_y_as_int = 1;
else
  plot_y_as_int = 0;  
end

valuePos = eXAxisSouthValuePos;
for posNo = 1:dlx:size(valuePos,1)

  if (plot_as_matrix == 1) | (plot_x_as_int == 1)
    text_str = sprintf('%d',Xc(posNo));
  else
    text_str = sprintf('%.2f',Xc(posNo));
  end
  etext(text_str,valuePos(posNo,1),...
	  valuePos(posNo,2)-2*eAxesTicLongLength,4,0);
end

valuePos = eYAxisWestValuePos;
for posNo = 1:dly:size(valuePos,1)
  
  if (plot_as_matrix == 1) | (plot_y_as_int == 1)
     text_str = sprintf('%d',Yc(posNo));
  else
    text_str = sprintf('%.2f',Yc(posNo));
  end
  etext(text_str,valuePos(posNo,1)-2*eAxesTicLongLength,...
	  valuePos(posNo,2),4,3);
end

if (plot_as_matrix == 0)
  if (PlotBoth==1)
    ePlotTitleText = '';
  end
  eimagesc(rot90(Zc),Cm,'e');
  if (ShowContours==1)
    econtour(rot90(Zc),ContourLevels,0,[1 1 1;0 0 0;0 0 0]);
  end
else
  ePlotTitleText     = 'Matrix View';
  ePlotTitleDistance = 5;
  eimagesc(Zc,Cm,'e');
  if (ShowContours==1)
    econtour(Zc,ContourLevels,0,[1 1 1;0 0 0;0 0 0]);
  end
  ePlotTitleText     = '';
end

end % if (PlotCartesian == 1) | (PlotBoth == 1)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

eclose;
ebbox(3,FileName);

fflush(stdout);