clear

CISM_DX_GLOBALS;

NDAYS       = 10;
LEAD_TIME   = 1;
threat(1)   = 60;
threat(2)   = 80;
MINY        = 0;
MINX        = 1;
MAXY        = 100;
YSTEP       = 20;
MAXX        = NDAYS;

load('./demo_1d.dat');

Xa       = demo_1d;

Xa       = Xa(1:365,:);
Xf       = Xa(30:size(Xa,1),:);
Xf       = unique(Xf,'rows');
Xa       = unique(Xa,'rows');

[Va,Vf,T]  = time_union(Xf,Xa,FLAG,'day');
L          = length(Va);
XLabels    = date_labels([1:L]',[1:L]',T(1,1:3));

% Change flag value to 1 for plotting
I           = find(Vf > 0.99*FLAG);
Vf(I)       = 1;
I           = find(Va > 0.99*FLAG);
Va(I)       = 1;

% Keep only last 30 points for plotting
Iplot       = [L-NDAYS+1:L]';
Vf          = Vf(Iplot);
Va          = Va(Iplot);
XLabels     = XLabels(Iplot,:);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% First Plot
eglobpar2;                      % get access to global parameters
einit2;

eWinWidth       = 200;
eWinHeight      = 140;
ePageWidth      = 1.1*eWinWidth;
ePageHeight     = 1.1*eWinHeight;

ePlotAreaHeight = 80;
ePlotAreaWidth  = 170;
ePlotAreaPos    = [20 40]; % Position of 0,0 on axes wrt bounding
                           % box set by eWinWidth eWinHeight

eopen2('./plot_1d_demo.eps'); % open eps-file and write eps-head

eaxes2([1 1 MAXX],XLabels,[MINY YSTEP MAXY],[]);

% Plot red strip
xb = [MINX MINX  MAXX MAXX];
yb = [MINY MAXY MAXY  MINY];
eplot2(xb,yb,'',-1,[1 0 0])
eplot2(xb,yb,'',-1,[1 0 0])

% Plot yellow strip
xb = [MINX MINX MAXX MAXX];
yb = [MINY threat(2) threat(2) MINY];
eplot2(xb,yb,'',-1,[1 1 0])

% Plot white strip
xb = [MINX MINX MAXX MAXX];
yb = [MINY threat(1) threat(1) MINY];
eplot2(xb,yb,'',-1,[1 1 1])

% Plot gray strip
xi = 0.5+L-LEAD_TIME-27;
xf = 0.5+L-LEAD_TIME-1;
xb = [xi xi xf xf];
yb = [MINY threat(1) threat(1) MINY];
eplot2(xb,yb,'27 days of most recent solar rotation',-1,[0.7 0.7 0.7])

% Plot grid lines
for i = 0:YSTEP:MAXY
  yh      = [i i];
  xh      = [MINX MAXX];
  eplot2(xh,yh,'',0,[0 0 0]);
end

% Plot right line
eplot2([MAXX MAXX],[MINY MAXY],'',0,[0 0 0]);

% Plot blue bars
LEAD_TIME = 1;
[xb yb]   = ebar2(Va,1,1,1,0.5+[0:length(Iplot)-1]); 
eplot2(xb,yb,'Measured Ap',-1,[0 0 1])

% Plot black outline
eplot2(xb,yb,'',0,[0 0 0]) 

% Plot last blue bar with proper width
if (0)
Date      = ymd(now);
W         = Date(L,4);
F         = W/24;
R         = L-LEAD_TIME-1+F;
xb        = [L-LEAD_TIME-1,L-LEAD_TIME-1,R,R];
yb        = [MINY Va(L-LEAD_TIME) Va(L-LEAD_TIME) MINY];
eplot2(xb,yb,'',-1,[0 0 1])
end

% Plot black outline
eplot2(xb,yb,'',0,[0 0 0]) 

% Plot black predition bars
LEAD_TIME = 1;
[xb yb]   = ebar2(Vf,0.6,1,1,0.5+[0:length(Iplot)-1]); 
eplot2(xb,yb,'Predicted Ap',-1,[0 0 0])

% Plot black outline
eplot2(xb,yb,'',0,[0 0 0],0.9) 
eplot2

% Add text for probability
x1 = xf+1;
y1 = threat(2)-2.0;
xpos=ePlotAreaPos(1)+(x1-ePlotAreaXValueStart)*ePlotAreaXFac/eFac;
ypos=ePlotAreaPos(2)+(y1-ePlotAreaYValueStart)*ePlotAreaYFac/eFac;
etext2('x',xpos,ypos,4,0)

% Add text for probability
x1 = xf+1;
y1 = threat(1)-3.5;
xpos=ePlotAreaPos(1)+(x1-ePlotAreaXValueStart)*ePlotAreaXFac/eFac;
ypos=ePlotAreaPos(2)+(y1-ePlotAreaYValueStart)*ePlotAreaYFac/eFac;
etext2('*',xpos,ypos,4,0)

x1 = 1;
y1 = (threat(2)+MAXY)*0.5;
xpos=ePlotAreaPos(1)+(x1-ePlotAreaXValueStart)*ePlotAreaXFac/eFac;
ypos=ePlotAreaPos(2)+(y1-ePlotAreaYValueStart)*ePlotAreaYFac/eFac;
etext2('High geomagnetic activity level',xpos,ypos,3,1)

x1 = 1;
y1 = (threat(1)+threat(2))*0.5;
xpos=ePlotAreaPos(1)+(x1-ePlotAreaXValueStart)*ePlotAreaXFac/eFac;
ypos=ePlotAreaPos(2)+(y1-ePlotAreaYValueStart)*ePlotAreaYFac/eFac;
etext2('Moderate geomagnetic activity level',xpos,ypos,3,1)

yh      = [threat(1) MAXY];
xh      = [(1+xf-0.5) (1+xf-0.5)];
eplot2(xh,yh,'',0,[0.5 0.5 0.5]);
yh      = [threat(1) MAXY];
xh      = [(1+xf+0.5) (1+xf+0.5)];
eplot2(xh,yh,'',0,[0.5 0.5 0.5]);


eplotlg2 (eFile,350,50,[1 1 1],0,0,'*   20.0% Probability of Ap > 60',...
	 eFonts(ePlotLegendTextFont,:),10);
eplotlg2 (eFile,350,60,[1 1 1],0,0,'x   10.0% Probability of Ap > 80',...
	 eFonts(ePlotLegendTextFont,:),10);	 

eplot2
eclose2

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
