function [B,Fnames] = loaddir(directoryname,STR)
% LOADDIR Load all data files in directory into cell array.
%
%    [D,Fnames] = LOADDIR attempts to use the Matlab LOAD command on each
%    file in the current directory.  Each cell is a file and Fnames are
%    the names of the files loaded.
%
%    D = LOADDIR(directoryname) where relative and absolute paths are
%    allowed.
%
%    D = LOADIR(directoryname,STR) does the above on any file
%    with a name that begins with STR.
%
%    See also LOAD.

% R.S. Weigel  

D = readdir(directoryname);

% Octave's readdir function changed sometime after 2.1.50 (output is cell).
% instead of char array.  This will break on Octave versions after 2.1.50
% that output a cell and if strvcat function cannot handle cell arrays.

if (iscell(D))
  if (is_octave)
    Dm = [];
    for i = 1:length(D)
      Dm = strvcat(Dm,D{i});
    end
    D = Dm;
  else
    D = strvcat(D);
  end
end

Files = D;
k = 0;

for i = 1:size(Files,1)
  fname = deblank(Files(i,:));
  if ~isempty(strmatch(STR,fname))
    k = k + 1;
    Fnames{k,1} = fname;
    B{k,1} = load([directoryname,'/',Fnames{k,1}]);
  end
end
