/* R.S. Weigel, 09/02/2004 */
#include "read_hdf_sd.h"

int free_SDS(SDS_structure *SDS, int return_data);
int read_hdf_sd(SDS_structure *SDS, int return_data, int verbosity);

/**************************************************************************/
int free_SDS(SDS_structure *SDS, int return_data)
{

  int i;

  /* Free allocated memory ***************************************/
  free(SDS->sd_filename);

  free(SDS->name);
  free(SDS->label);
  free(SDS->unit);
  free(SDS->format);
  free(SDS->coord_system);
  free(SDS->attr_lengths);
  free(SDS->dim_sizes);

  free(SDS->dims.n_values);
  free(SDS->dims.data_type);
  free(SDS->dims.start);
  free(SDS->dims.stride);
  free(SDS->dims.edges);

  for (i = 0; i < SDS->n_attributes; i++) {
    free(SDS->attributes.attr_values[i]);
    free(SDS->attributes.attr_names[i]);
  }
  free(SDS->attributes.attr_values);
  free(SDS->attributes.attr_names);

  if (return_data == 1){
    if (SDS->num_type == 5)
      free(SDS->float_array_1D);
    if (SDS->num_type == 6)
      free(SDS->double_array_1D);
  }
  /***************************************************************/  

}
/**************************************************************************/

/**************************************************************************/
int read_hdf_sd(SDS_structure *SDS, int return_data, int verbosity) 
{

  int32 n_file_attrs;
  char attr_name[MAX_LEN];
  char attr_value[MAX_LEN];

  int32 num_type, istat;
  int32 n_values;
  int32 data_type;
  int i,j,N=1,Na=1;

  SDS->sd_id        = -1;
  SDS->n_datasets   = -1;  
  SDS->sds_id       = -1;
  SDS->name         = (char*)calloc((int) MAX_LEN,sizeof(char));
  SDS->label        = (char*)calloc((int) MAX_LEN,sizeof(char));
  SDS->unit         = (char*)calloc((int) MAX_LEN,sizeof(char));
  SDS->format       = (char*)calloc((int) MAX_LEN,sizeof(char));
  SDS->coord_system = (char*)calloc((int) MAX_LEN,sizeof(char));
  SDS->attr_lengths = (int32*)calloc((int) MAX_LEN,sizeof(int32));
  SDS->num_type     = -1;
  SDS->n_attributes = -1;
  SDS->rank         = -1;
  SDS->dim_sizes    = (int32*)calloc((int) MAX_VAR_DIMS,sizeof(int32));

  SDS->dims.data_type  = (char*)calloc((int) MAX_LEN,sizeof(char));
  SDS->dims.n_dims     = (int32*)calloc((int) MAX_VAR_DIMS,sizeof(int32));
  SDS->dims.n_attrs    = (int32*)calloc((int) MAX_VAR_DIMS,sizeof(int32));
  SDS->dims.n_values   = (int32*)calloc((int) MAX_VAR_DIMS,sizeof(int32));

  /* Open the file and initiate the SD interface. **********************/
  if (verbosity == 1)
    printf("Attempting to open file %s for READ access\n",
	   SDS->sd_filename);

   SDS->sd_id = SDstart(SDS->sd_filename, DFACC_READ); 

   if (SDS->sd_id != FAIL){
     if (verbosity == 1)
       printf("Completed opening file %s for READ access\n",
	      SDS->sd_filename);
   }
   else {
     printf("Error when attempting to open file %s for READ access\n",
	    SDS->sd_filename);
     return 0;
   }
   /********************************************************************/

   /* Determine the contents of the file. ******************************/
   if (verbosity == 1)
     printf("Attempting SDfileinfo call to file %s.\n",SDS->sd_filename);

   istat = SDfileinfo(SDS->sd_id, &SDS->n_datasets, &n_file_attrs);

   if (SDS->sd_id != FAIL){
     if (verbosity == 1)
       printf("Completed SDfileinfo call to file %s.\n",SDS->sd_filename);
   }
   else {
     printf("Error during SDfileinfo call to file %s.\n",SDS->sd_filename);
     return 0;
   }
   /********************************************************************/

  if (verbosity == 1) {
    printf("___________________________________________________\n");
    printf("sd_filename     = %s\n",SDS->sd_filename);
    printf("n_datasets      = %d\n",SDS->n_datasets);
    printf("n_file_attrs    = %d\n",n_file_attrs);
    printf("___________________________________________________\n");
  }
	
   /* Get info for requested sds in the file. **************************/
   SDS->sds_id = SDselect(SDS->sd_id, SDS->sds_index);
   istat       = SDgetinfo(SDS->sds_id, SDS->name, &SDS->rank, 
			   SDS->dim_sizes, &SDS->num_type, &SDS->n_attributes);
   istat       = SDgetdatastrs(SDS->sds_id, SDS->label, SDS->unit,
			       SDS->format, SDS->coord_system, MAX_LEN);

   /* Get info about each dimension of the sds                         */
   SDS->dims.names  = (char **)calloc((int) SDS->rank, sizeof(int));
   for (i = 0; i < SDS->rank; i++){   
     SDS->dims.names[i] = (char *)calloc((int) MAX_LEN, sizeof(char));
     istat = SDdiminfo(i, SDS->dims.names[i], SDS->dims.n_values[i],
		       SDS->dims.data_type[i], SDS->dims.n_attrs[i]);
   }
   /********************************************************************/

   /* Get length of each attribute so we can allocate for them ********/ 
   if (verbosity == 1)
     printf("Attempting SDattrinfo call.\n");fflush(stdout);

   SDS->attributes.attr_names  = 
      (char **)calloc((int) SDS->n_attributes, sizeof(int));

   for (i = 0; i < SDS->n_attributes; i++) {
     SDS->attributes.attr_names[i]  = 
       (char *)calloc((int) MAX_LEN, sizeof(char));
   }


   for (i = 0; i < SDS->n_attributes; i++){
     istat = SDattrinfo(SDS->sds_id, i, 
			SDS->attributes.attr_names[i],
			&data_type,
			&SDS->attr_lengths[i]);
   }
  
  if (verbosity == 1)
    printf("Completed SDattrinfo call.\n");fflush(stdout);
   /********************************************************************/

  /* Allocate required memory for atttributes in sds *******************/
  SDS->attributes.attr_values = (char **)calloc(SDS->n_attributes,sizeof(int));
  
  for (i = 0; i < SDS->n_attributes; i++) {
    Na = SDS->attr_lengths[i];

    SDS->attributes.attr_values[i] = 
      (char *)calloc(Na*sizeof(char),sizeof(char));

  }
  /********************************************************************/

  /* Read the attributes **********************************************/
  for (i = 0; i < SDS->n_attributes; i++){
    istat = SDreadattr(SDS->sds_id, i, SDS->attributes.attr_values[i]);   
  }
  /********************************************************************/


  /* Read the attribute values ****************************************/
  for (i = 0; i < SDS->n_attributes; i++){
    istat = SDreadattr(SDS->sds_id, i, SDS->attributes.attr_values[i]);   
  }
  /********************************************************************/

  /***************************************************************/
  if (verbosity == 1) {
    printf("___________________________________________________\n");
    printf("sds_id        = %d\n",SDS->sds_id);
    printf("sds_index     = %d of %d\n", 
	   SDS->sds_index, (SDS->n_datasets)-1);
    printf("name          = %s\n", SDS->name);
    printf("label         = %s\n", SDS->label);
    printf("unit          = %s\n", SDS->unit);
    printf("format        = %s\n", SDS->format);
    printf("coord_system  = %s\n", SDS->coord_system);
    printf("num_type      = %d\n", SDS->num_type);
    printf("n_attributes  = %d\n", SDS->n_attributes);
    printf("rank          = %d\n", SDS->rank);
    for (i = 0; i < SDS->rank; i++){
      printf("dim_sizes[%d] = %d\n", i, SDS->dim_sizes[i]);
      printf("data_type[%d] = %d\n", i, SDS->dims.data_type[i]);
    }
    printf("___________________________________________________\n");
    fflush(stdout);
  }
  /***************************************************************/

  /**********************************************************************/
  if (return_data == 1) {

    /* Define the location, pattern, and size of the data set */
    if (SDS->dims.start[0] == -1){
      for (i = 0; i < SDS->rank; i++) {
	SDS->dims.start[i]  = 0;
	SDS->dims.stride[i] = 1;
	SDS->dims.edges[i]  = SDS->dim_sizes[i];;
	SDS->dims.Npts[i]   = SDS->dim_sizes[i];;
      } 
    }
    if (verbosity == 1) {
      for (i = 0; i < SDS->rank; i++) {
	printf("start[%d] = %d\n",i,SDS->dims.start[i]);
	printf("stride[%d] = %d\n",i,SDS->dims.stride[i]);
	printf("edges[%d] = %d\n",i,SDS->dims.edges[i]);
	printf("Npts[%d] = %d\n",i,SDS->dims.Npts[i]);
      }
    }

    /*********************************************************************/
    if (verbosity == 1){
      printf("Attempting SDreaddata call to file %s.\n",SDS->sd_filename);
      fflush(stdout);
    }

    for (i = 0; i < SDS->rank; i++)  
      N = N*SDS->dims.Npts[i];

    if (SDS->num_type == 5) {
      SDS->float_array_1D = 
	(float*)malloc(sizeof(float)*(int) N);
      istat = SDreaddata (SDS->sds_id,
			  SDS->dims.start,
			  SDS->dims.stride,
			  SDS->dims.edges,
			  (VOIDP) SDS->float_array_1D);
    } else if (SDS->num_type == 6) {
      SDS->double_array_1D = 
	(double*)malloc(sizeof(double)*(int) N);
      istat = SDreaddata (SDS->sds_id,
			  SDS->dims.start,
			  SDS->dims.stride,
			  SDS->dims.edges,
			  (VOIDP) SDS->double_array_1D);
    } else {
      printf("Error: SDS array is not a double or float.\n");
      fflush(stdout);
      return 0;
    }      
    
    if (verbosity == 1){
      printf("Completed SDreaddata call.\n",SDS->sd_filename);
      fflush(stdout);
    }
    /*********************************************************************/

    /*********************************************************************/
    if (verbosity == 1){

      printf ("\nFirst 5 points in array out of %d: \n",N);

      if (SDS->num_type == 5) {
	for (i = 0; i < 5; i++)
	  printf ("%10.2f", SDS->float_array_1D[i]);
	printf("\n");
      }

      if (SDS->num_type == 6) {
	for (i = 0; i < 5; i++)
	  printf ("%10.2f", SDS->double_array_1D[i]);
	printf("\n");
      }

      printf ("\nAttributes associated with above array: \n");
      for (i = 0; i < SDS->n_attributes; i++) {
	printf("attr_name  = %s\n",SDS->attributes.attr_names[i]);
	printf("attr_value = %s\n",SDS->attributes.attr_values[i]);
	//N = strlen(SDS.attributes.attr_values[i]);
	//printf("length of attr_values[%d]=%d\n",i,N);
      }
    }
    /*********************************************************************/

  } /* end of if (return_data == 1) ************************************/
  
  /* Terminate access to sds and close the file. *****************/
  if (verbosity == 1){
    printf("Attempting to close file %s.\n",SDS->sd_filename);
    fflush(stdout);
  }
  
  istat = SDendaccess(SDS->sds_id);
  istat = SDend(SDS->sd_id);
  
  if (istat != FAIL){
    if (verbosity == 1)
      printf("Completed closing file.\n");
    fflush(stdout);
    return 1;
  }
  else {
    printf("Error when closing file %s.\n",SDS->sd_filename);
    fflush(stdout);
    return 0;
  }
  /***************************************************************/    

}
/**************************************************************************/



