## Copyright (C) 2000  Etienne Grossmann
##
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

## rmpath(dir1,...)
##
##   Removes dir1,... from the current LOADPATH.
## 
## newpath = rmpath(path, dir1, ...)
## 
##   Removes dir1,... from path.
##
## See also: addpath, savepath.

## Author:        Etienne Grossmann <etienne@cs.uky.edu>
## Modified-by:   R.S. Weigel <rweigel@gmu.edu>
##                Ignore single trailing slash in path. 
# Last modified: June 2005

##PKGADD: mark_as_command('rmpath')

function ret = rmpath(varargin)

  if nargout == 0,
    path = LOADPATH ;
  else
    path = varargin{1};
  endif


  ##printf('initial path=<%s>\n',path);
  strip_system_path = 0;
  for arg=nargout+1:length(varargin)
    p = varargin{arg};
    lp = length(p); 

    ## '' is the system path
    if lp==0, strip_system_path = 1; LOADPATH=''; DEFAULT_LOADPATH='';,end

    # remove single trailing slash
    if length(p) > 1
      if p(end) == "/" 
	if length(p) > 2
	  # Allow two trailing slashes
	  if isempty(strmatch(path(end-1:end),"//"))
	    p = p(1:end-1);
	  else
	    warning('Double trailing slash in path is Octave-only feature');
	  end
	end
      end
    end

    if length(p)==1
      if ~isempty(strmatch(p(1),".")) 
	warning("Removal of '.' from path is Octave-only feature");
      end
    end
    if length(p)==2
      if ~isempty(strmatch(p(1:2),"./")) 
	warning("Removal of '.' from path is Octave-only feature");
      end
    end

    lp  = length(p); 
    lpo = length(path); 

    lo = 0 ;
    while lo != length(path),	# Loop while I can substitute
      lo = length(path) ;
      ## strip ':p:'
      path = strrep(path,sprintf(":%s:",p),":") ;
      ## strip ':p/:'
      path = strrep(path,sprintf(":%s/:",p),":") ;
    end

    if length(path) > lp+1 
      ## strip 'p:...'
      if strcmp(path(1:lp+1),sprintf("%s:",p))
	path = path(lp+2:end);
      end
      if strcmp(path(1:lp+2),sprintf("%s/:",p))
	path = path(lp+2:end);
      end
      
    end

    if length(path) > lp+1 
      ## strip '...:p' -> '...'
      if strcmp(path(end-lp:end),sprintf(":%s",p))
      path = path(1:end-lp-1);
      end
      ## strip '...:p/' -> '...'
      if strcmp(path(end-lp-1:end),sprintf(":%s/",p))
	path = path(1:end-lp-2);
      end
    end

    ## strip 'p:' and ':p' -> ':'
    if length(path) == lp+1 && (strcmp(path,sprintf("%s:",p)) || strcmp(path,sprintf(":%s",p)))
      path = ':';
    end

    ## strip 'p' -> ''
    if length(path) == lp && strcmp(path,p)
      path = '';
    end

    ##printf('strip <%s> path=<%s>\n',p,path);

    if (lpo==length(path)) 
      if (nargout==0) ## Kludge to suppress warning from first call to
		      ## rmpath by addpath.
	warning('rmpath: Directory %s is not in path',p)
      end
    end
  end


  if strip_system_path && strcmp(path,':'), path = ''; end

  if nargout > 0
    ret = path;
  elseif !strcmp(LOADPATH,path),
    # printf("rmpath : loadpath is changed\n") ;
    LOADPATH = path;
  end

%!assert(rmpath(':',''),'');
%!assert(rmpath('hello:',''),'hello');
%!assert(rmpath('hello:world',''),'hello:world');
%!assert(rmpath(':hello:world',''),'hello:world');
%!assert(rmpath(':hello:world:',''),'hello:world');
%!assert(rmpath(':hello::world:',''),'hello:world');

%!assert(rmpath('hello','hello'),'');
%!assert(rmpath(':hello','hello'),':');
%!assert(rmpath('hello:','hello'),':');
%!assert(rmpath('hello:hello','hello'),'');
%!assert(rmpath('hello:hello:hello','hello'),'');
%!assert(rmpath('hello:hello:hello:hello','hello'),'');
%!assert(rmpath(':hello:hello','hello'),':');
%!assert(rmpath('hello:hello:','hello'),':');
%!assert(rmpath('hello','world'),'hello');
%!assert(rmpath(':hello','','hello'),'');
%!assert(rmpath(':hello','hello',''),'');

%!assert(rmpath('hello:world','hello','world'),'');
%!assert(rmpath('hello:world:','hello','world'),':');
%!assert(rmpath(':hello:world:','hello','world'),':');

%!assert(rmpath('hello:world','','hello','world'),'');
%!assert(rmpath('hello:world:','','hello','world'),'');
%!assert(rmpath(':hello:world:','','hello','world'),'');

%!assert(rmpath('hello:world','hello'),'world');
%!assert(rmpath('hello:world','world'),'hello');
%!assert(rmpath('hello:world:','hello'),'world:');
%!assert(rmpath('hello:world:','world'),'hello:');
%!assert(rmpath(':hello:world:','hello'),':world:');
%!assert(rmpath(':hello:world:','world'),':hello:');
