## Copyright (C) 2000 Paul Kienzle
##
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

## -*- texinfo -*-
## @deftypefn {Function File} {} intersect(@var{a}, @var{b})
##
## Return the elements in both @var{a} and @var{b}, sorted in ascending
## order. If @var{a} and @var{b} are both column vectors return a column
## vector, otherwise return a row vector.
##
## @deftypefnx {Function File} {[@var{c}, @var{i}, @var{j}] = } intersect (...)
## 
## Return index vectors @var{i} and @var{i}, where @var{c} = @var{a}(@var{i})
## and @var{c} = @var{b}(@var{j}).
## 
## @end deftypefn
## @seealso{unique, union, setxor, setdiff, ismember}

function [c,ia,ib] = intersect(a,b)
  if ( nargin == 3 )
    usage ("intersect (a, b) - rows option is not implemented");
  endif
  if ( nargin != 2 )
    usage ("intersect (a, b)");
  endif

  if ( isempty (a) || isempty (b) )
    c = [];
  else

  ## Save memory by not computing index vectors if not requested.
  if (nargout == 1) 
	       

    ## form a and b into sets
    au = unique (a);
    bu = unique (b);
    
    ## keep duplicates
    ab  = [ au(:) ; bu(:) ]; clear au bu;
    c   = sort (ab); 
    
    n  = length(c);
    ia  = find (c(1:n-1) == c(2:n));
    c = c (ia);
    if ( size (b, 1) == 1 || size (a, 1) == 1 )
      c = c.';
    endif
   
   endif

  ## Requested index vectors.   
  if (nargout > 1) 

    ## form a and b into sets
    [au,ia] = unique (a);
    [bu,ib] = unique (b);
    
    ## keep duplicates
    ab  = [ au(:) ; bu(:) ]; clear au bu
    iab = [ ia(:) ; ib(:) ];
    [c,ic] = sort (ab);
    iab = iab(ic);

    n  = length(c);
    ia  = find (c(1:n-1) == c(2:n));
    c = c (ia);
    ia = iab(ia); clear iab;
    if ( size (b, 1) == 1 || size (a, 1) == 1 )
      c = c.';
      ia = ia.';
    endif
    endif
    
    if (nargout == 3)
      [jnk,ib] = intersect(b,a);
    endif

  endif
  
endfunction
