function [cout,hc,hax] = pcolor_plot(X,Y,Z,zlims);
%PCOLOR_PLOT Makes color plot using PCOLOR
%
%  PCOLOR_PLOT centers the axis ticks to center of color block.
%
%  Note that if using in a subplot, colormap cannot change.  
%
%  [cout,hc] = PCOLOR_PLOT(Z,zlims)  Uses PCOLOR to plot data in range
%              max_Z = zlims(1), min_Z = zlims(2).  If zlims has one element,  
%              min_Z defults to 0.  
%
%  [cout,hc] = PCOLOR_PLOT(X,Y,Z,zlims)  Uses PCOLOR to plot data on grid
%              specified by X and Y matrices.  
%              
%              Elements with Z > max_Z are plotted with a point.  
%              Elements with Z == isnan are plotted with an x.
%              Elements with Z == isinf are plotted with a *.
%
%  Use zlims = 0
%  
%  To do: Implement min_Z in code.   
  
if (nargin < 3 )
  Z     = X;
  if (nargin == 1)
    zlims = max(Z(:));
  end
  if (nargin == 2)
    zlims = Y;
  end
  X     = [1:size(Z,1)]';
  X     = repmat(X,1,size(Z,2));
  Y     = [1:size(Z,2)];
  Y     = repmat(Y,size(Z,1),1);
end

if (~exist('zlims'))
  zlims = max(Z(:));
end

if (length(zlims) == 2)
  if (zlims(2) < -3)
    minz = floor(zlims(2));
  else
    minz = zlims(2);
  end
else
  minz = floor(min(Z(:)));
  %minz = 0;
end

if (zlims(1)>1)
  maxz = ceil(zlims(1));
else
  maxz = zlims(1);
end

if (maxz-minz > 5)
  colormap(flipud(hot(2*(maxz-minz))));
else
  colormap(flipud(hot(10)));
end

% put a check to see if in a subplot here?
% maxz = max(Z(:));
colormap(flipud(hot(10)));

Yo           = Y;
Xo           = X;
Zo           = Z;

delta_Y      = (Y(1,2)-Y(1,1)); % Shift so block is centered.
delta_X      = (X(2,1)-X(1,1)); % Shift so block is centered.

X            = [X ; X(end,:)  + delta_X];
X            = [X   X(:,end)] - delta_X/2;
Y            = [Y   Y(:,end)  + delta_Y];
Y            = [Y ; Y(end,:)] - delta_Y/2;
Z            = [Z   Z(:,end)];
Z            = [Z ; Z(end,:)];

Imin         = find(Z < minz);
Z(Imin)      = minz;
Imax         = find(Z > maxz);
Z(Imax)      = maxz;
Iinf         = find(isinf(Z)==1);
Z(Iinf)      = minz;
Inan         = find(isnan(Z)==1);
Z(Inan)      = minz;

% Trick to set colorbar limits
Z_orig       = Z(end,end); 
Z(end,end)   = maxz;
Z_orig2      = Z(1,1); 
Z(1,1)       = minz;

cout         = pcolor(X,Y,Z);
	       set(cout,'LineStyle','none');
hc           = colorbar;
gc           = get(hc,'Position');
gc(1)        = gc(1);
               set(hc,'Position',gc);
               set(get(hc,'Ylabel'),'HorizontalAlignment','left')
               hold on;
%	       set(cout,'Visible','off'); % Makes .eps file smaller by
                                          % removing this layer.

% Plot again
Z(end,end)   = Z_orig;
Z(1,1)       = Z_orig2;
cout         = pcolor(X,Y,Z);
               hax = gca;
	       view(2);
	       hold on;
I            = find(isnan(Zo) == 1);
II           = find(isinf(Zo) == 1);
III          = find(Zo > maxz);
IV           = find(Zo < minz);
               plot(Xo(I),Yo(I),'rx');
	       plot(Xo(II),Yo(II),'r*');
	       plot(Xo(III),Yo(III),'r.','MarkerSize',10);
	       plot(Xo(IV),Yo(IV),'b.','MarkerSize',10);
g1           = get(get(cout,'Parent'),'Position');
	       axis tight;
               set((get(cout,'Parent')),'Box','on')
               %set(get(hc,'Ylabel'),'String','Z','FontSize',18)
	       %set(get(hc,'Ylabel'),'Rotation',0)
	       set(cout,'LineStyle','none');
