function Z = block_corrcoef_nonflag(X,Y,L,FLAGval,COND)
%BLOCK_CORRCOEF_NONFLAG Block correlation coefficient
%
%   Z = BLOCK_CORRCOEF_NONFLAG(X,Y,L) has columns that are the block
%   correlation coefficient of 1-D arrays X and Y with nonoverlapping
%   window size L.  If any value in window L is non-NaN, it is used for the
%   average.
%
%   Z has floor(size(X,1)/L) rows (i.e., if last block is not full, the
%   extra data points are ignored).
%
%   Z = BLOCK_CORRCOEF_NONFLAG(X,Y,L,FLAG,EXACT) See IS_FLAG for defaults
%   and definitions.  
%  
%   See also BLOCK_CORRCOEF, *_NONFLAG.

% R.S. Weigel, 04/02/2004.

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%  
if (nargin < 3)
  FLAGval = NaN;
end
if (nargin < 4)
  EXACT = 1;
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%  

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%  
M = size(X,1);
N = size(X,2);

if (N > M)
  X = X';
  Y = Y';
  M = size(X,1);
  N = size(X,2);
  if (N > 1)
    error('X and Y must be 1-D arrays');
  end
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

F  = floor(M/L);
Xr = reshape(X(1:F*L),L,F);
Yr = reshape(Y(1:F*L),L,F);

for i = 1:F
  Z(i,1)  = corrcoef_nonflag(Xr(:,i),Yr(:,i),FLAGval,COND);
end
