function [Z,Ng] = block_mean_nonflag(X,L,FLAG,EXACT)
%BLOCK_MEAN_NONFLAG Block average of non-FLAG elements.
%
%   Y = BLOCK_MEAN_NONFLAG(X,L) has columns that are the block mean of
%   the columns of X with nonoverlapping window size L.  If any value
%   in window L is non-NaN, it is used for the average.  
%
%   Y has the same number of columns as X and has floor(size(X,1)/L) 
%   rows (i.e., if last block is not full, the extra data points 
%   are ignored).
%
%   Example: block_mean_nonflag([1 3;2 NaN],2) = [1.5;2]
%
%   Y = BLOCK_MEAN_NONFLAG(X,L,FLAG,EXACT) If EXACT = 0, substracts mean of
%   elements less than FLAG.  EXACT = 1, substracts off elements not equal
%   to flag.  EXACT = 3, subtracts off elements with absolute value less
%   than FLAG.  Default is EXACT = 1;
%
%   See also BLOCK_MEAN, *_NONFLAG.

% R.S. Weigel, 04/02/2004.
  
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%  
if (nargin < 3)
  FLAG  = NaN;
end
if (nargin < 4)
  EXACT = 1;
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%  
  
M  = size(X,1);
N  = size(X,2);
F  = floor(M/L);

if (L == 1)
  error('Input L must be greater than 1');
end

for i = 1:N
  Y = reshape(X(1:F*L,i),L,F);
  if (nargout > 1)
    [tempZ,tempNg] = mean_nonflag(Y,1,FLAG,EXACT);
    Z(:,i)  = tempZ';
    Ng(:,i) = tempNg';
  else
    Z(:,i) = mean_nonflag(Y,1,FLAG,EXACT)';  
  end
end
