function str80 = wrap80(str_in)
%WRAP80 Reshape single-row string to have 80 columns
%
%   str80 = wrap80(str_in) Reshapes str_in into a matrix with 80 columns.
%           Last row of matrix contains blank padding, if required.
%
%           Any existing newlines in str_in are replaced with blanks
%           before processing begins.
%
%   See also: FPRINTF80.
  

% Should be named LINEWRAP(str_in,N), with N=80 default.  

% remove any existing newlines
newline = sprintf('\n');

str_in = strrep(str_in,newline,' ');

I = findstr(str_in,newline);
if (~isempty(I))
  str_in(I) = ' ';
end
  
if (size(str_in,1)>1)
  error('Input string must have a single row.');
end

L = length(str_in);
if (L < 81)
  str80 = [str_in,blanks(80-L),newline];
  return;
end

I      = findstr(':',str_in);
line1  = str_in(1:80);
str_in = str_in(81:end);

if (~isempty(I))
  padl   = I(1)+1;
  Nw     = 80 - padl;
else
  Nw    = 80;
  padl  = 0;
end

if (length(str_in) < Nw)
  str80  = [line1, newline , repmat(' ',size(str_in,1),padl) , str_in , ...
	    newline];
  return;
end

padr   = Nw*ceil(length(str_in)/Nw)-length(str_in);
str_in = [str_in , blanks(padr)];
str80  = reshape(str_in',Nw,length(str_in)/Nw)';
str80  = [repmat(' ',size(str80,1),padl) , str80];
str80  = [line1 ; str80];
str80  = [str80 , repmat(newline,size(str80,1),1)];
