function File = call_perlfile(Perlfile,Args,FromDir,File)
%CALL_PERLFILE Call a perl script from a given directory
%
%   CALL_PERLFILE(Perlfile) executes the Perl program Perlfile.
%   If Perlfile is in the loadpath, absolute path is not needed.
%
%   CALL_PERLFILE(Perlfile,ARGS) passes Perlfile the command line arguments
%   ARGS.
%
%   CALL_PERLFILE(Perlfile,ARGS,FromDir) calls Perlfile after changing to
%   directory FromDir.
%
%   File = CALL_PERLFILE(Perlfile,ARGS,FromDir,File) attempts to return the
%   result of "load File" after execution of Perlfile.  Set FromDir = './'
%   if Perlfile should be called from the current directory.
%
%   See also PERLPATH.
  
CISM_DX_GLOBALS;

Perlfile = file_in_loadpath(Perlfile);

if (~exist('CISM_DX_PERL_PATH'))
  CISM_DX_PERL_PATH = perlpath;
end

if (nargin < 3) & (nargout > 0)
  error('File is a required input when File is a requested output.');
end

if (nargin < 2)
  Args = '';
end

if (nargin > 2)
  curr_dir = pwd;
  cd(FromDir);
end

command_str = sprintf('%s %s %s',CISM_DX_PERL_PATH,Perlfile,Args);
fprintf('call_perl.m: call_perl.m is executing system command:  \n%s\nfrom directory %s\n',...
	command_str,pwd);

fflush(stdout);
system(command_str);

if (nargin > 3)
  File = eval(sprintf('load %s',File));
end

if (nargin > 2)
  cd(curr_dir);
end
