function [XLabels,I] = year_labels(DAYS_PLOT,DAY_0,FORMAT)
%YEAR_LABELS Form strings for year labels
%
%  XLabels = YEARS_LABELS(DAYS_PLOT,DAY_0)
%  
%  DAYS_PLOT  A vector of day numbers that are plotted.
%  DAY_0     The day of the first data point [YYYY,MM,DY].
%  
%  Example:
%  [XLabels,I] = year_labels([1:367],[2000,1,1]) returns
%  XLabels     = ['2000','2001']
%  I           = [1,367]
%  
%  See also YEAR_LABELS_DEMO, DATE_LABELS.
  
% R.S. Weigel 05/27/2004.  

if (nargin < 3)
  FORMAT = 2;
end

L       = length(DAYS_PLOT);
I       = [366:365:L];
Y0      = DAY_0(1);
I       = I + cumsum(is_leap_year(Y0:Y0+length(I)-1));
I       = [1,I];

[XLabels,I] = date_labels(DAYS_PLOT,I',[DAY_0(1),1,1],10);

dY = 0;
if (dY > 1)

  K        = [1:dY:length(I)];
  I        = I(K);
  XLabels  = XLabels(K,:);

  if (K(end) ~= length(I))
    Yf = str2num(XLabels(end,:));
    Nd = number_days(Yf,Yf+dY)+1;
    I  = [I;I(end)+Nd];
    K  = [K,K(end)+dY];
    XLabels = [XLabels ; num2str(Yf+dY)];
  end
  

  
end
