function [V,ATTR] = CDAWeb_extract(DATADIR,SATINFO,var_no)
%CDAWEB_EXTRACT Called by CDAWeb.m. Do not call directly.
%
% Put data on 1-minute time grid.  
%

TSDS_GLOBALS; % Get global variables and path settings

[Time,Data,FLAGval,d_i,Nd,Years] = CDAWeb_extract_var(DATADIR,SATINFO,var_no);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Sometimes there are repeats in time value which causes 
% interpolation to fail.  This removes repeats.
LTime     = length(Time);
[Time,I1] = unique(Time);
if (LTime > length(Time))
  Data = Data(I1,:);
  fprintf('Removed %d repeated time values (%.4f percent).\n',...
	  LTime-length(Time),100.0*(LTime-length(Time))/length(Time));
end

% Time is in units of Matlab datenum (number of days since 00-Jan-0000).
T = 60*1440*(Time-d_i);   % T is seconds from start of first year

% Replace values greater than 0.99*abs(FLAGval) with TSDS_FLAG.
Data = reflag(Data,abs(0.99*FLAGval),TSDS_FLAG,2);

Ti    = [30:60:Nd*60*1440]';  % The time vector to interpolate to
Datai = interp1g(T,Data,Ti,'nearest');

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
for i = 1:size(Datai,2)
  V{i}            = Datai(:,i);
  ATTR{i}.Year_o  = Years{1};
  ATTR{i}.Year_f  = Years{2};
  ATTR{i}.Size    = size(V{i});
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

