function [Time,Data,FLAGval,d_i,Nd,Years,MADE_W_FILES] = CDAWeb_extract_var(DATADIR,SATINFO,var_no)
%CDAWEB_EXTRACT_VAR Called by CDAWEB_EXTRACT.m. Do not call directly.
%
%   Tested in Matlab 7.0 on RHEL 3.0.  
%
%   Could be made Octave-compatable by writing CDFREAD and CAT functions.
%   (CAT is available after approximately version 2.1.50)
%   Would also need to replace DATENUM call with DAY_NUMBER and
%   DIR with READDIR.
% 
%   This function is very slow, but does not need to be executed often.
%   Can deal with files that contain more than one days worth of data
%   (such as the Ulysses vhm_1min files).
%
%   Time and d_i is according to TODATENUM.
  
%  R.S Weigel, November 2003, December 2004.

more off;

% Get global variables and path setting
TSDS_GLOBALS;

% Get directory listing
FILE_LIST = readdir(DATADIR);

k = 1;
I = [];
for i = 1:length(FILE_LIST)
  % Find directory names that begin with '19' or '20'.
  if ~isempty(strmatch('19',FILE_LIST{i})) | ...
	~isempty(strmatch('20',FILE_LIST{i})) 
    if isempty(findstr('tgz',FILE_LIST{i})) % Ignore tgz files
      I(k) = i;
      k = k+1;
    end
  end
end

if (isempty(I))
  error('Did not find subdirectories matching 19* or 20* in directory %s\n',...
	DATADIR);
end

% Year of first data file
first_file  = FILE_LIST{I(1)};
Year_o      = first_file;

% Year of last data file
last_file  = FILE_LIST{I(end)};
Year_f     = last_file;
%Year_f     = Year_o;

Years = {Year_o,Year_f};

% String for boundary dates
startdate  = sprintf('1/1/%s',Year_o);
enddate    = sprintf('12/31/%s',Year_f);

% Convert date to an integer
d_i        = datenum(startdate);
d_f        = datenum(enddate);
Nd         = d_f - d_i + 1; % Number of days of data
Nbytes     = 0;             % Counter for monitoring memory usage

% Loop over each day
for i = 1:Nd

  % Create file name string
  day       = datestr(d_i+i-1,30);
  fname     = sprintf('%s/%s/%s_%s*.cdf',...
		      DATADIR,day(1:4),SATINFO.fname_base,day(1:8));

  % Search for matching filename in directory listing
  D = dir(fname); 
  % If multiple matches to file name pattern
  if (length(D) > 1)
    fprintf('Found multiple files for same date. ');
    fprintf('Using file with highest version number.\n');
    fprintf('Files are named: ');
    temp_name = cat(1,D.name);
    for zz = 1:size(temp_name,1)
      fprintf('%s ',temp_name(zz,:));
    end
    fprintf('\n');
  end

  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
  % If no match to file pattern
  if (~isempty(D))
    fid   = 3;
    fname = sprintf('%s/%s/%s',DATADIR,day(1:4),D(end).name);
  else
    fid   = -1;
    fname = '';
  end
  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
  
  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
  if (fid == 3) % If requested file exists

    xInfo      = cdfinfo(fname);

    % Get flag value
    tempcell = getfield(xInfo.VariableAttributes,'FILLVAL');
    ind      = strmatch(SATINFO.varname{var_no},tempcell(:,1),'exact');
    if (isempty(ind))
      fprintf('Did not find variable %s in CDF file\n',...
	      SATINFO.varname{var_no});
    end
    FLAGV2(i) = tempcell{ind,2};
    
    fprintf('Extracting data from %s\n',fname);
    temp = cdfread(fname,'Variable',SATINFO.timename);

    if (~isempty(temp)) % b/c TODATENUM does not work for empty array.
      temp1{i}   = (todatenum(cat(2,temp{:})))';
    else
      temp1{i}   = []; 
    end

    temp       = cdfread(fname,'Variable',SATINFO.varname{var_no});
    temp2{i}   = SATINFO.unitfactor(var_no)*double(cat(2,temp{:})');
    
    MADE_W_FILES{i,1} = fname;

    Nbytes = Nbytes + (1+2*3)*8*length(temp);
    if (Nbytes > 5e8) % More than approximately 500 MB
      fprintf('Nbytes = %e\n',Nbytes);
    end
  end
  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
  
end

Time    = cat(1,temp1{:}) ; clear temp1;
Data    = cat(1,temp2{:}) ; clear temp2;


if (isinteger(Data)) % This happens for GEOTAIL magnetic field and causes
		     % problems with interp1
  Data = double(Data);
end
if (isinteger(FLAGV2)) % This happens for GEOTAIL magnetic field and causes
		       % problems with interp1
  FLAGV2 = double(FLAGV2);
end

FLAGV2  = unique(FLAGV2);
FLAGval = max(abs(FLAGV2));
Nf      = length(FLAGV2); % Number of unique flag values

if (Nf > 1)
  warning(['Flag value is not unique. Reflagging using' ...
	   ' max(abs(FLAGS)).']);
  for i = 1:Nf
    Data = reflag(Data,FLAGV2(i),FLAGval,1);
  end
end
