function S = COHOWeb_info(NAME,Attr_in)

  
if (nargin == 0)  
  S = {'voyager1','voyager2','pioneer10','pioneer11','helios1','helios2'};
  return;
end

if (strmatch('helios2',NAME,'exact'))
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
S(1).satellite      = 'helios2';            % Satellite name
S(1).DATA_DIR       = 'helios/helios2/merged';
                                                
S(1).fname_base     = 'helios2';              
S(1).timename       = 'Epoch';       
S(1).varname{1}     = {'BR_RTN'};
S(1).varname{2}     = {'BT_RTN'};
S(1).varname{3}     = {'BN_RTN'};
S(1).varname{4}     = {'Dist_HGI'};
S(1).varname{5}     = {'Lat_HGI'};
S(1).varname{6}     = {'Long_HGI'};
S(1).varname{7}     = {'V'};
S(1).varname{8}     = {'N'};
S(1).varname{9}     = {'Temp'};
S(1).unitfactor(1:9) = 1; % Unit conversion factors

for i = 1:9
S(1).Attr(i).PPD      = '24';		    
S(1).Attr(i).TimeUnit = 'hour';		    
S(1).Attr(i).Source   = ['ftp://nssdcftp.gsfc.nasa.gov/spacecraft_data/',...
		        S(1).DATA_DIR];
S(1).Attr(i).README   = 'http://nssdc.gsfc.nasa.gov/cohoweb/html/cw_data.html';
S(1).Attr(i).Acknowledgement = 'See http://nssdc.gsfc.nasa.gov/cohoweb/html/cw_data.html';
end

S(1).Attr(1).Name{1}  = 'Helios 2 Br (COHOWeb 1-hour merged)';
S(1).Attr(1).CoordinateSystem = 'RTN';
S(1).Attr(1).Unit     = 'nT';

S(1).Attr(2).Name{1}  = 'Helios 2 Bt (COHOWeb 1-hour merged)';
S(1).Attr(2).CoordinateSystem = 'RTN';
S(1).Attr(2).Unit     = 'nT';
 
S(1).Attr(3).Name{1}  = 'Helios 2 Bn (COHOWeb 1-hour merged)';
S(1).Attr(3).CoordinateSystem = 'RTN';
S(1).Attr(3).Unit     = 'nT';

S(1).Attr(4).Name{1}  = 'Helios 2 Radial Distance (COHOWeb 1-hour merged)';
S(1).Attr(4).CoordinateSystem = 'HGI';
S(1).Attr(4).Unit     = 'AU';

S(1).Attr(5).Name{1}  = 'Helios 2 Latitude (COHOWeb 1-hour merged)';
S(1).Attr(5).CoordinateSystem = 'HGI';
S(1).Attr(5).Unit     = 'Degrees';

S(1).Attr(6).Name{1}  = 'Helios 2 Longitude (COHOWeb 1-hour merged)';
S(1).Attr(6).CoordinateSystem = 'HGI';
S(1).Attr(6).Unit     = 'Degrees';

S(1).Attr(7).Name{1}  = 'Helios 2 solar wind speed (COHOWeb 1-hour merged)';
S(1).Attr(7).CoordinateSystem = '-';
S(1).Attr(7).Unit     = 'km/s';

S(1).Attr(8).Name{1}  = 'Helios 2 proton density (COHOWeb 1-hour merged)';
S(1).Attr(8).CoordinateSystem = '-';
S(1).Attr(8).Unit     = '#/cc';

S(1).Attr(9).Name{1}  = 'Helios 2 proton temperature (COHOWeb 1-hour merged)';
S(1).Attr(9).CoordinateSystem = '-';
S(1).Attr(9).Unit     = 'Degrees Kelvin';
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
end

if (strmatch('helios1',NAME,'exact'))
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
S(1).satellite      = 'helios1';            % Satellite name
S(1).DATA_DIR       = 'helios/helios1/merged';
                                                
S(1).fname_base     = 'helios1';              
S(1).timename       = 'Epoch';       
S(1).varname{1}     = {'BR_RTN'};
S(1).varname{2}     = {'BT_RTN'};
S(1).varname{3}     = {'BN_RTN'};
S(1).varname{4}     = {'Dist_HGI'};
S(1).varname{5}     = {'Lat_HGI'};
S(1).varname{6}     = {'Long_HGI'};
S(1).varname{7}     = {'V'};
S(1).varname{8}     = {'N'};
S(1).varname{9}     = {'Temp'};
S(1).unitfactor(1:9) = 1; % Unit conversion factors

for i = 1:9
S(1).Attr(i).PPD      = '24';		    
S(1).Attr(i).TimeUnit = 'hour';		    
S(1).Attr(i).Source   = ['ftp://nssdcftp.gsfc.nasa.gov/spacecraft_data/',...
		        S(1).DATA_DIR];
S(1).Attr(i).README   = 'http://nssdc.gsfc.nasa.gov/cohoweb/html/cw_data.html';
S(1).Attr(i).Acknowledgement = 'See http://nssdc.gsfc.nasa.gov/cohoweb/html/cw_data.html';
end

S(1).Attr(1).Name{1}  = 'Helios 1 Br (COHOWeb 1-hour merged)';
S(1).Attr(1).CoordinateSystem = 'RTN';
S(1).Attr(1).Unit     = 'nT';

S(1).Attr(2).Name{1}  = 'Helios 1 Bt (COHOWeb 1-hour merged)';
S(1).Attr(2).CoordinateSystem = 'RTN';
S(1).Attr(2).Unit     = 'nT';
 
S(1).Attr(3).Name{1}  = 'Helios 1 Bn (COHOWeb 1-hour merged)';
S(1).Attr(3).CoordinateSystem = 'RTN';
S(1).Attr(3).Unit     = 'nT';

S(1).Attr(4).Name{1}  = 'Helios 1 Radial Distance (COHOWeb 1-hour merged)';
S(1).Attr(4).CoordinateSystem = 'HGI';
S(1).Attr(4).Unit     = 'AU';

S(1).Attr(5).Name{1}  = 'Helios 1 Latitude (COHOWeb 1-hour merged)';
S(1).Attr(5).CoordinateSystem = 'HGI';
S(1).Attr(5).Unit     = 'Degrees';

S(1).Attr(6).Name{1}  = 'Helios 1 Longitude (COHOWeb 1-hour merged)';
S(1).Attr(6).CoordinateSystem = 'HGI';
S(1).Attr(6).Unit     = 'Degrees';

S(1).Attr(7).Name{1}  = 'Helios 1 solar wind speed (COHOWeb 1-hour merged)';
S(1).Attr(7).CoordinateSystem = '-';
S(1).Attr(7).Unit     = 'km/s';

S(1).Attr(8).Name{1}  = 'Helios 1 proton density (COHOWeb 1-hour merged)';
S(1).Attr(8).CoordinateSystem = '-';
S(1).Attr(8).Unit     = '#/cc';

S(1).Attr(9).Name{1}  = 'Helios 1 proton temperature (COHOWeb 1-hour merged)';
S(1).Attr(9).CoordinateSystem = '-';
S(1).Attr(9).Unit     = 'Degrees Kelvin';
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
end

if (strmatch('pioneer11',NAME,'exact'))
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
S(1).satellite      = 'pioneer11';            % Satellite name
S(1).DATA_DIR       = 'pioneer/pioneer11/merged';
                                                
S(1).fname_base     = 'pioneer11';              
S(1).timename       = 'Epoch';       
S(1).varname{1}     = {'BR_RTN'};
S(1).varname{2}     = {'BT_RTN'};
S(1).varname{3}     = {'BN_RTN'};
S(1).varname{4}     = {'Dist_HGI'};
S(1).varname{5}     = {'Lat_HGI'};
S(1).varname{6}     = {'Long_HGI'};
S(1).varname{7}     = {'V'};
S(1).varname{8}     = {'N'};
S(1).varname{9}     = {'Temp'};
S(1).unitfactor(1:9) = 1; % Unit conversion factors

for i = 1:9
S(1).Attr(i).PPD      = '24';		    
S(1).Attr(i).TimeUnit = 'hour';		    
S(1).Attr(i).Source   = ['ftp://nssdcftp.gsfc.nasa.gov/spacecraft_data/',...
		        S(1).DATA_DIR];
S(1).Attr(i).README   = 'http://nssdc.gsfc.nasa.gov/cohoweb/html/cw_data.html';
S(1).Attr(i).Acknowledgement = 'See http://nssdc.gsfc.nasa.gov/cohoweb/html/cw_data.html';
end

S(1).Attr(1).Name{1}  = 'Pioneer 11 Br (COHOWeb 1-hour merged)';
S(1).Attr(1).CoordinateSystem = 'RTN';
S(1).Attr(1).Unit     = 'nT';

S(1).Attr(2).Name{1}  = 'Pioneer 11 Bt (COHOWeb 1-hour merged)';
S(1).Attr(2).CoordinateSystem = 'RTN';
S(1).Attr(2).Unit     = 'nT';
 
S(1).Attr(3).Name{1}  = 'Pioneer 11 Bn (COHOWeb 1-hour merged)';
S(1).Attr(3).CoordinateSystem = 'RTN';
S(1).Attr(3).Unit     = 'nT';

S(1).Attr(4).Name{1}  = 'Pioneer 11 Radial Distance (COHOWeb 1-hour merged)';
S(1).Attr(4).CoordinateSystem = 'HGI';
S(1).Attr(4).Unit     = 'AU';

S(1).Attr(5).Name{1}  = 'Pioneer 11 Latitude (COHOWeb 1-hour merged)';
S(1).Attr(5).CoordinateSystem = 'HGI';
S(1).Attr(5).Unit     = 'Degrees';

S(1).Attr(6).Name{1}  = 'Pioneer 11 Longitude (COHOWeb 1-hour merged)';
S(1).Attr(6).CoordinateSystem = 'HGI';
S(1).Attr(6).Unit     = 'Degrees';

S(1).Attr(7).Name{1}  = 'Pioneer 11 solar wind speed (COHOWeb 1-hour merged)';
S(1).Attr(7).CoordinateSystem = '-';
S(1).Attr(7).Unit     = 'km/s';

S(1).Attr(8).Name{1}  = 'Pioneer 11 proton density (COHOWeb 1-hour merged)';
S(1).Attr(8).CoordinateSystem = '-';
S(1).Attr(8).Unit     = '#/cc';

S(1).Attr(9).Name{1}  = 'Pioneer 11 proton temperature (COHOWeb 1-hour merged)';
S(1).Attr(9).CoordinateSystem = '-';
S(1).Attr(9).Unit     = 'Degrees Kelvin';
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
end

if (strmatch('pioneer10',NAME,'exact'))
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
S(1).satellite      = 'pioneer10';            % Satellite name
S(1).DATA_DIR       = 'pioneer/pioneer10/merged';
                                                
S(1).fname_base     = 'pioneer10';              
S(1).timename       = 'Epoch';       
S(1).varname{1}     = {'BR_RTN'};
S(1).varname{2}     = {'BT_RTN'};
S(1).varname{3}     = {'BN_RTN'};
S(1).varname{4}     = {'Dist_HGI'};
S(1).varname{5}     = {'Lat_HGI'};
S(1).varname{6}     = {'Long_HGI'};
S(1).varname{7}     = {'V'};
S(1).varname{8}     = {'N'};
S(1).varname{9}     = {'Temp'};
S(1).unitfactor(1:9) = 1; % Unit conversion factors

for i = 1:9
S(1).Attr(i).PPD      = '24';		    
S(1).Attr(i).TimeUnit = 'hour';		    
S(1).Attr(i).Source   = ['ftp://nssdcftp.gsfc.nasa.gov/spacecraft_data/',...
		        S(1).DATA_DIR];
S(1).Attr(i).README   = 'http://nssdc.gsfc.nasa.gov/cohoweb/html/cw_data.html';
S(1).Attr(i).Acknowledgement = 'See http://nssdc.gsfc.nasa.gov/cohoweb/html/cw_data.html';
end

S(1).Attr(1).Name{1}  = 'Pioneer 10 Br (COHOWeb 1-hour merged)';
S(1).Attr(1).CoordinateSystem = 'RTN';
S(1).Attr(1).Unit     = 'nT';

S(1).Attr(2).Name{1}  = 'Pioneer 10 Bt (COHOWeb 1-hour merged)';
S(1).Attr(2).CoordinateSystem = 'RTN';
S(1).Attr(2).Unit     = 'nT';
 
S(1).Attr(3).Name{1}  = 'Pioneer 10 Bn (COHOWeb 1-hour merged)';
S(1).Attr(3).CoordinateSystem = 'RTN';
S(1).Attr(3).Unit     = 'nT';

S(1).Attr(4).Name{1}  = 'Pioneer 10 Radial Distance (COHOWeb 1-hour merged)';
S(1).Attr(4).CoordinateSystem = 'HGI';
S(1).Attr(4).Unit     = 'AU';

S(1).Attr(5).Name{1}  = 'Pioneer 10 Latitude (COHOWeb 1-hour merged)';
S(1).Attr(5).CoordinateSystem = 'HGI';
S(1).Attr(5).Unit     = 'Degrees';

S(1).Attr(6).Name{1}  = 'Pioneer 10 Longitude (COHOWeb 1-hour merged)';
S(1).Attr(6).CoordinateSystem = 'HGI';
S(1).Attr(6).Unit     = 'Degrees';

S(1).Attr(7).Name{1}  = 'Pioneer 10 solar wind speed (COHOWeb 1-hour merged)';
S(1).Attr(7).CoordinateSystem = '-';
S(1).Attr(7).Unit     = 'km/s';

S(1).Attr(8).Name{1}  = 'Pioneer 10 proton density (COHOWeb 1-hour merged)';
S(1).Attr(8).CoordinateSystem = '-';
S(1).Attr(8).Unit     = '#/cc';

S(1).Attr(9).Name{1}  = 'Pioneer 10 proton temperature (COHOWeb 1-hour merged)';
S(1).Attr(9).CoordinateSystem = '-';
S(1).Attr(9).Unit     = 'Degrees Kelvin';
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
end

if (strmatch('voyager1',NAME,'exact'))
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
S(1).satellite      = 'voyager1';            % Satellite name
S(1).DATA_DIR       = 'voyager/voyager1/merged';
                                                
S(1).fname_base     = 'voyager1';              
S(1).timename       = 'Epoch';       
S(1).varname{1}     = {'BR_RTN'};
S(1).varname{2}     = {'BT_RTN'};
S(1).varname{3}     = {'BN_RTN'};
S(1).varname{4}     = {'Dist_HGI'};
S(1).varname{5}     = {'Lat_HGI'};
S(1).varname{6}     = {'Long_HGI'};
S(1).varname{7}     = {'V'};
S(1).varname{8}     = {'N'};
S(1).varname{9}     = {'Temp'};
S(1).unitfactor(1:9) = 1; % Unit conversion factors

for i = 1:9
S(1).Attr(i).PPD      = '24';		    
S(1).Attr(i).TimeUnit = 'hour';		    
S(1).Attr(i).Source   = ['ftp://nssdcftp.gsfc.nasa.gov/spacecraft_data/',...
		        S(1).DATA_DIR];
S(1).Attr(i).README   = 'http://nssdc.gsfc.nasa.gov/cohoweb/html/cw_data.html';
S(1).Attr(i).Acknowledgement = 'See http://nssdc.gsfc.nasa.gov/cohoweb/html/cw_data.html';
end

S(1).Attr(1).Name{1}  = 'Voyager 1 Br (COHOWeb 1-hour merged)';
S(1).Attr(1).CoordinateSystem = 'RTN';
S(1).Attr(1).Unit     = 'nT';

S(1).Attr(2).Name{1}  = 'Voyager 1 Bt (COHOWeb 1-hour merged)';
S(1).Attr(2).CoordinateSystem = 'RTN';
S(1).Attr(2).Unit     = 'nT';
 
S(1).Attr(3).Name{1}  = 'Voyager 1 Bn (COHOWeb 1-hour merged)';
S(1).Attr(3).CoordinateSystem = 'RTN';
S(1).Attr(3).Unit     = 'nT';

S(1).Attr(4).Name{1}  = 'Voyager 1 Radial Distance (COHOWeb 1-hour merged)';
S(1).Attr(4).CoordinateSystem = 'HGI';
S(1).Attr(4).Unit     = 'AU';

S(1).Attr(5).Name{1}  = 'Voyager 1 Latitude (COHOWeb 1-hour merged)';
S(1).Attr(5).CoordinateSystem = 'HGI';
S(1).Attr(5).Unit     = 'Degrees';

S(1).Attr(6).Name{1}  = 'Voyager 1 Longitude (COHOWeb 1-hour merged)';
S(1).Attr(6).CoordinateSystem = 'HGI';
S(1).Attr(6).Unit     = 'Degrees';

S(1).Attr(7).Name{1}  = 'Voyager 1 solar wind speed (COHOWeb 1-hour merged)';
S(1).Attr(7).CoordinateSystem = '-';
S(1).Attr(7).Unit     = 'km/s';

S(1).Attr(8).Name{1}  = 'Voyager 1 proton density (COHOWeb 1-hour merged)';
S(1).Attr(8).CoordinateSystem = '-';
S(1).Attr(8).Unit     = '#/cc';

S(1).Attr(9).Name{1}  = 'Voyager 1 proton temperature (COHOWeb 1-hour merged)';
S(1).Attr(9).CoordinateSystem = '-';
S(1).Attr(9).Unit     = 'Degrees Kelvin';
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
end

if (strmatch('voyager2',NAME,'exact'))
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
S(1).satellite      = 'voyager2';            % Satellite name
S(1).DATA_DIR       = 'voyager/voyager2/merged';
                                                
S(1).fname_base     = 'voyager2';              
S(1).timename       = 'Epoch';       
S(1).varname{1}     = {'BR_RTN'};
S(1).varname{2}     = {'BT_RTN'};
S(1).varname{3}     = {'BN_RTN'};
S(1).varname{4}     = {'Dist_HGI'};
S(1).varname{5}     = {'Lat_HGI'};
S(1).varname{6}     = {'Long_HGI'};
S(1).varname{7}     = {'V'};
S(1).varname{8}     = {'N'};
S(1).varname{9}     = {'Temp'};

S(1).unitfactor(1:9) = 1; % Unit conversion factors

for i = 1:9
S(1).Attr(i).PPD      = '24';		    
S(1).Attr(i).TimeUnit = 'hour';		    
S(1).Attr(i).Source   = ['ftp://nssdcftp.gsfc.nasa.gov/spacecraft_data/',...
		        S(1).DATA_DIR];
S(1).Attr(i).README   = 'http://nssdc.gsfc.nasa.gov/cohoweb/html/cw_data.html';
S(1).Attr(i).Acknowledgement = 'See http://nssdc.gsfc.nasa.gov/cohoweb/html/cw_data.html';
end


S(1).Attr(1).Name{1}  = 'Voyager 2 Br (COHOWeb 1-hour merged)';
S(1).Attr(1).CoordinateSystem = 'RTN';
S(1).Attr(1).Unit     = 'nT';

S(1).Attr(2).Name{1}  = 'Voyager 2 Bt (COHOWeb 1-hour merged)';
S(1).Attr(2).CoordinateSystem = 'RTN';
S(1).Attr(2).Unit     = 'nT';
 
S(1).Attr(3).Name{1}  = 'Voyager 2 Bn (COHOWeb 1-hour merged)';
S(1).Attr(3).CoordinateSystem = 'RTN';
S(1).Attr(3).Unit     = 'nT';

S(1).Attr(4).Name{1}  = 'Voyager 2 Radial Distance (COHOWeb 1-hour merged)';
S(1).Attr(4).CoordinateSystem = 'HGI';
S(1).Attr(4).Unit     = 'AU';

S(1).Attr(5).Name{1}  = 'Voyager 2 Latitude (COHOWeb 1-hour merged)';
S(1).Attr(5).CoordinateSystem = 'HGI';
S(1).Attr(5).Unit     = 'Degrees';

S(1).Attr(6).Name{1}  = 'Voyager 2 Longitude (COHOWeb 1-hour merged)';
S(1).Attr(6).CoordinateSystem = 'HGI';
S(1).Attr(6).Unit     = 'Degrees';

S(1).Attr(7).Name{1}  = 'Voyager 2 solar wind speed (COHOWeb 1-hour merged)';
S(1).Attr(7).CoordinateSystem = '-';
S(1).Attr(7).Unit     = 'km/s';

S(1).Attr(8).Name{1}  = 'Voyager 2 proton density (COHOWeb 1-hour merged)';
S(1).Attr(8).CoordinateSystem = '-';
S(1).Attr(8).Unit     = '#/cc';

S(1).Attr(9).Name{1}  = 'Voyager 2 proton temperature (COHOWeb 1-hour merged)';
S(1).Attr(9).CoordinateSystem = '-';
S(1).Attr(9).Unit     = 'Degrees Kelvin';
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if (nargin > 1)
  for i = 1:length(Attr_in)

    Attr{i}        = ts_attr;
    Attr{i}.Year_o = Attr_in{i}.Year_o;
    Attr{i}.Year_f = Attr_in{i}.Year_f;
    Attr{i}.Size   = Attr_in{i}.Size;
    Attr{i}.Label   = sprintf('%s %s (COHOWeb 1-hour merged %s)',...
			     S.satellite,...
			     S.varname{i}{1},...
			     S.fname_base);
  
    Attr{i}.Name             = S(1).Attr(i).Name{1};
    Attr{i}.CoordinateSystem = S(1).Attr(i).CoordinateSystem;
    Attr{i}.Unit             = S(1).Attr(i).Unit;
    Attr{i}.PPD              = S(1).Attr(i).PPD;
    Attr{i}.TimeUnit         = S(1).Attr(i).TimeUnit;
    Attr{i}.Source           = S(1).Attr(i).Source;
    Attr{i}.README           = S(1).Attr(i).README;
    Attr{i}.Acknowledgement  = S(1).Attr(i).Acknowledgement;
  end

  S = Attr;

  return;
  
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
