function FILES = CSSDP_extract(DATA_DIR,parse_files)
%CSSDP_EXTRACT
%
%   Files = CSSDP_EXTRACT(Data_dir)
%
%   Transform and concatanate all 1-min .wdc files into .dat files (with no
%   strings) using a Perl script.  Load this .dat file and save as a .mat
%   file.
%
%   ASCII file abc_MIN.dat has columns YEAR MONTH DAY HOUR ELEMENT DATA AVE
%
%   abc is the magnetometer 3-letter code.
%   ELEMENT is 0,1,2,3,4,5 for D,H,X,Y,Z,F
%   DATA is 60 columns corresponding to 60 mins in hour
%
%   .mat file abc_min.mat has matrix variable named abc_hr with contents of
%   .dat file abc_min.dat.
%
%   Files = DMI_1_MIN_EXTRACT(Data_dir,parse_files) If parse_files = 0, do
%   not call Perl script and use existing .dat files to create .mat files.
%
%
  
if (nargin < 2)
  parse_files = 1;
end
  
TSDS_GLOBALS;  

TEMPDIR = [TSDS_DATA_TEMP,'/cssdp'];
FILES = [];
if (parse_files == 1)

  system(sprintf('rm -rf %s/*.dat ; mkdir -p %s',TEMPDIR,TEMPDIR)); 

  D = readdir(DATA_DIR);

  % Octave's readdir function changed sometime after 2.1.50 (output is cell).
  % instead of char array.  This will break on Octave versions after 2.1.50
  % that output a cell and if strvcat function cannot handle cell arrays.
  
  if (iscell(D))
    if (is_octave)
    Dm = [];
    for i = 1:length(D)
      Dm = strvcat(Dm,D{i});
    end
    D = Dm;
    else
      D = strvcat(D);
    end
    
  end

  for i = 1:size(D,1)

    FILE = deblank(D(i,:));

    if (~isempty(findstr('gz',FILE)))

      com1 = sprintf('cd %s ; ',DATA_DIR);
      com2 = sprintf('tar zxvf %s; ',FILE);
      com3 = sprintf('%s %s/CSSDP_extract.pl %s %s; rm -f *.MAG',...
		     TSDS_PERL,TSDS_PERLFILES,TEMPDIR,DATA_DIR);
    
      com = [com1,com2,com3];

      system(com); % Call the Perl program.
    
    end
  
  end

end
