function [Files_good,Attr] = DMI_1_min_extract(DATA_DIR,parse_files)
%DMI_1_MIN_EXTRACT
%
%   Files = DMI_1_MIN_EXTRACT(Data_dir)
%
%   Transform and concatanate all 1-min .wdc files into .dat files (with no
%   strings) using a Perl script.  Load this .dat file and save as a .mat
%   file.
%
%   ASCII file abc_MIN.dat has columns YEAR MONTH DAY HOUR ELEMENT DATA AVE
%
%   abc is the magnetometer 3-letter code.
%   ELEMENT is 0,1,2,3,4,5 for D,H,X,Y,Z,F
%   DATA is 60 columns corresponding to 60 mins in hour
%
%   .mat file abc_min.mat has matrix variable named abc_hr with contents of
%   .dat file abc_min.dat.
%
%   Files = DMI_1_MIN_EXTRACT(Data_dir,parse_files) If parse_files = 0, do
%   not call Perl script and use existing .dat files to create .mat files.
%
%
  
if (nargin < 2)
  parse_files = 1;
end
  
TSDS_GLOBALS;  

TEMPDIR = [TSDS_DATA_TEMP,'/wdc1min'];
today_yr = date;
today_yr = str2num(today_yr(8:end));
%today_yr   = 2003;
%initial_yr = 2003;
initial_yr = 1969;


if (parse_files == 1)

system(sprintf('rm -rf %s ; mkdir -p %s',...
	       TEMPDIR,TEMPDIR)); 

for i = initial_yr:today_yr

com1 = sprintf('cd %s/%d ; ',DATA_DIR,i);
com2 = sprintf('unzip -o \\*.zip ; %s %s/wdcMIN2dat.pl %s ; rm -f *.WDC',...
	       TSDS_PERL,TSDS_PERLFILES,TEMPDIR);

system([com1,com2]); % Call the Perl program.
end
end

Files = readdir(TEMPDIR);

if (parse_files == 0) % Do not recreate .mat files

  k = 1;
  for i = 1:size(Files,1)

    if ~isempty(findstr(Files(i,:),'.mat')) % If file has extension .mat

      mag = Files(i,1:3);
      var = Files(i,1:9);
      
      Files_good{k} = sprintf('%s/%s',TEMPDIR,Files(i,:));
      Attr{k}.Name = sprintf('%s',mag);    

      k = k + 1;
    
    end
  end
  
end      

if (parse_files == 1)

k = 1;
for i = 1:size(Files,1)

  if ~isempty(findstr(Files(i,:),'.dat')) % If file has extension .dat

    mag = Files(i,1:3);
    var = Files(i,1:9);
    
    try % to load .dat file created by wdcMIN2dat.pl.

      % Load transformed .dat files.
      com = sprintf('load %s',sprintf('%s/%s',TEMPDIR,Files(i,:)));
      fprintf('Evaluating command: %s\n',com);
      eval(com);
      
      % Save all data for given mag in an individual .mat binary file.
      if (is_octave)
	com=sprintf('save -mat-binary %s/%s.mat %s ; clear %s;',...
		    TEMPDIR,var,var,var);
      else
	com = sprintf('save %s/%s.mat %s ; clear %s ;',...
		      TEMPDIR,var,var,var);
      end
      
      fprintf('Evaluating command: %s\n',com);
      eval(com);
      
      datfile = sprintf('%s/%s',TEMPDIR,Files(i,:));
      rm(datfile);      
      fprintf('Removed %s\n',datfile);
      
      Files_good{k} = sprintf('%s/%s.mat',TEMPDIR,var);
      Attr{k}.Name = sprintf('%s',mag);

      k = k + 1;

      
    catch % catch, report failure, and continue
      
      fprintf('Problems with load command: %s\n',lasterr);
      fprintf('Continuing.\n');
      
    end

  end % if strmatch
  
end

end % if parse_files
