%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This code has been tested in Matlab 6.5 on RHEL 3.0
% Data are extracted from file measurements/original_data/DMI_WDC/data
% R.S. Weigel 04/03/2004
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear;

% Get global variables and path setting
CISM_DX_GLOBALS;

mag_data_info;

end_year      = 2002;
DATA_DIR      = [CISM_DX_DATA_FULL_ROOT,...
		 'measurements/original_data/DMI_WDC/'];
SAVE_LOCATION = [CISM_DX_DATA_FULL_ROOT,...
		 'measurements/uniform_time_series/Ground_Magnetometers/DMI/'];
DEMO_LOCATION = [CISM_DX_DATA_ROOT,'demo_data/'];
Dmat          = [CISM_DX_DATA_FULL_ROOT,...
		 'measurements/original_data/DMI_WDC/matfiles/'];
Dzip          = [CISM_DX_DATA_FULL_ROOT,...
		 'measurements/original_data/DMI_WDC/zipfiles/'];

MAGLIST_TO_MAKE = MAGLIST_DMI; % (To remake all data)
%MAGLIST_TO_MAKE = ['cmo '];    % (To remake only a few)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Download and extract all data
if (1)
for ii = 1:size(MAGLIST_TO_MAKE,1)
  
  i = strmatch(MAGLIST_TO_MAKE(ii,:),MAGLIST_DMI);
  
  MAGf = MAGLIST_DMI(i,:);
  MAG  = MAGLIST_DMI(i,1:3);

  dmi_download(MAG,[YEARS_DMI(i,1):YEARS_DMI(i,2)],Dzip);
  
  for j = 1:3
    % Puts data into .mat file by year and component.
    dmi_extract(MAG,[YEARS_DMI(i,1):YEARS_DMI(i,2)],COORDSYS_DMI(i,j),Dzip,Dmat);
  end
  
end
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Check all DMI data by visual inspection
if (1) 
for ii = 1:size(MAGLIST_TO_MAKE,1)

  i = strmatch(MAGLIST_TO_MAKE(ii,:),MAGLIST_DMI);  

  years = [YEARS_DMI(i,1):YEARS_DMI(i,2)];
  for j = 1:3
    X  = mag_data_load(MAGLIST_DMI(i,1:3),years,...
		       COORDSYS_DMI(i,j),directory_dmi,FLAG_DMI(i,j));
    Xs = sort(X);
    L  = floor(0.8*length(Xs));
    setpos;
    plot(Xs(L:end),'.');grid on;
    title(sprintf('i=%d %s %s %d-%d',i,...
		  MAGLIST_DMI(i,:),COORDSYS_DMI(i,j),years(1),years(end)));
    S = input('Hit return to continue, or enter maximum y value to plot.','s');
    if (~isempty(S))
      S2 = input('enter minimum y value to plot.','s');
      plot(X(1:end),'.');grid on;    
      yaxes([str2num(S2) str2num(S)])
      title(sprintf('i=%d %s %s %d-%d',...
		    i,MAGLIST_DMI(i,:),COORDSYS_DMI(i,j),years(1),years(end)));
      year_ticklabels(years(1),1,4);
      input('Continue?');
    end
      clear X;
  end
end
end

% Thses numbers were determined by visual inspection of plots generated above
% and must be copied into mag_data_info.m

clear FLAG_DMI;

FLAG_DMI(:,1) = [99999     ; 99999     ; 99999     ; 99999     ; 99999 ;...
		 49999     ; 49999     ; 99999     ; 99999     ; 99999 ;...
		 99999     ; 99999     ; 29999     ; 7999      ; 4999  ;...
		 39999     ; 69999     ; 59999     ; 29999     ; 79999 ;...
		 89999     ; 69999     ; 49999     ; 99999     ; 99999 ;...
		 59999     ; 59999     ; 99999     ; 99999     ; 99999 ;...
		 99999     ; 99999     ; 19999     ; 9999      ; 59999 ];

FLAG_DMI(:,2) = [99999     ; 49999     ; 49999     ; 99999     ; 99999 ;...
		 49999     ;   599     ; 99999     ; 99999     ; 99999 ;...
		 99999     ; 99999     ; 29999     ; 7999      ; 4999  ;...
		 39999     ; 69999     ; 59999     ; 29999     ; 79999 ;...
		 99999     ; 19999     ; 49999     ; 99999     ; 99999 ;...
		 99999     ; 99999     ; 99999     ; 99999     ; 99999 ;...
		 99999     ; 99999     ; 99999     ; 99999     ; 99999 ];
		 
FLAG_DMI(:,3) = [99999     ; 99999     ; 99999     ; 99999     ; 99999 ;...
		 59999     ; 49999     ; 99999     ; 99999     ; 99999 ;...
		 99999     ; 99999     ; 29999     ; 7999      ; 4999  ;...
		 39999     ; 69999     ; 59999     ; 29999     ; 79999 ;...
		 99999     ; 89999     ; 49999     ; 99999     ; 99999 ;...
		 99999     ; 99999     ; 99999     ; 99999     ; 99999 ;...
		 99999     ; 99999     ; 99999     ; 99999     ; 99999 ];

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% reflag the data
datastore_dmi_not_reflagged = directory_dmi;
datastore_dmi               = directory_dmi;

for ii = 1:size(MAGLIST_TO_MAKE,1)

  i = strmatch(MAGLIST_TO_MAKE(ii,:),MAGLIST_DMI);  
  allyears = [YEARS_DMI(i,1):YEARS_DMI(i,2)];
  for yr = 1:length(allyears)
    for j = 1:3
    X     = mag_data_load(MAGLIST_DMI(i,1:3),allyears(yr),...
			  COORDSYS_DMI(i,j),datastore_dmi_not_reflagged,99999);
    % Should use reflag.m here
    Ib    = find(X >= 0.99*FLAG_DMI(i,j));
    X(Ib) = 99999;
    MAG   = MAGLIST_DMI(i,1:3);
    COMPONENT = COORDSYS_DMI(i,j);
    
    fprintf('Saving %s/%s_%s_%d.mat\n',SAVE_LOCATION,MAG,COMPONENT,allyears(yr));

    if (COMPONENT == 'X')
      eval(sprintf('save %s%s_%s_%d.mat X',...
		   SAVE_LOCATION,MAG,COMPONENT,allyears(yr)));
      clear X;
    end
    if (COMPONENT == 'Y')
      Y = X;
      eval(sprintf('save %s%s_%s_%d.mat Y',...
		   SAVE_LOCATION,MAG,COMPONENT,allyears(yr)));
      clear Y;
    end
    if (COMPONENT == 'Z')
      Z = X;
      eval(sprintf('save %s%s_%s_%d.mat Z',...
		   SAVE_LOCATION,MAG,COMPONENT,allyears(yr)));
      clear Z;
    end
    if (COMPONENT == 'H')
      H = X;
      eval(sprintf('save %s%s_%s_%d.mat H',...
		   SAVE_LOCATION,MAG,COMPONENT,allyears(yr)));
      clear H;
    end
    if (COMPONENT == 'D')
      D = X;
      eval(sprintf('save %s%s_%s_%d.mat D',...
		   SAVE_LOCATION,MAG,COMPONENT,allyears(yr)));
      clear D;
    end
    end
  end
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

