function [V,ATTR] = ISGI_extract_qd(DATA_DIR)

% Get global variables and path setting
TSDS_GLOBALS;

% R.S. Weigel 07/13/2004

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Load the data after transforming original data to a matrix data file
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
com = sprintf('cd %s ; %s %s/qd2matrix.pl',...
	      DATA_DIR,TSDS_PERL,TSDS_PERLFILES);
system(com);

X = load(sprintf('%s/data_cat.matrix',DATA_DIR));
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% corresponding to its quiet day rank in its month.  The second column has
% values of 1, -1, or -2.  A selected quiet day is considered not really
% quiet and is marked by the -1 if Ap was greater than 6, or marked by -2 if
% Ap was less or equal 6 and either one Kp value greater than 3 or two Kp
% values greater than 2+.
%
% The first column of variable disturbed_days has a value of 1-5
% corresponding to its disturbed day rank in its month.  The second column
% has values of 1, or -1.  A selected disturbed day is considered not really
% disturbed and marked by -1 if Ap was less than 20.

% Matrix X has format
% Column  1     = Month
% Column  2     = Year
% Columns 3-12  = Quietest days in month
% Column  13-17 = Most disturbed days in month
%
% A selected quiet day is considered not really quiet and is marked by the
% fraction 0.1 following the day number if Ap greater than 6, or marked by
% the fraction 0.2 if Ap less or equal 6 and either one Kp value greater than 3
% or two Kp values greater than 2+.  A selected disturbed day is considered
% not really disturbed and marked by the fraction 0.3 if Ap less than 20.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Quiet Days
M    = repmat(X(:,1),1,10)';
M    = M(:);
Y    = repmat(X(:,2),1,10)';
Y    = Y(:);
Year_o = Y(1);
Year_f = Y(end);

DAY  = X(:,3:12)';
DAY  = DAY(:);
Q    = ones(length(DAY),1);
RANK = repmat([1:10]',size(X,1),1);

I     = find( round(10*(DAY-floor(DAY))) == 1);
Q(I)  = -1;  % Not really quiet
I     = find( round(10*(DAY-floor(DAY))) == 2);
Q(I)  = -2;  % Not really quiet

quiet     = [Y,M,floor(DAY),Q];
I         = find(Y <= Year_f);
quiet     = quiet(I,:);
rank      = RANK(I);

No  = day_number(Year_o,1,1);
Nf  = day_number(Year_f,12,31);
Nq  = day_number(quiet(:,1:3)) - No + 1;

temp1          = zeros(Nf-No+1,1);
temp2          = zeros(Nf-No+1,1);
temp1(Nq,1)    = quiet(:,4);
temp2(Nq,1)    = rank;
quiet_days     = [temp1,temp2];

V{1}           = quiet_days(:,1);
V{2}           = quiet_days(:,2);

Attr.Year_o = num2str(Year_o);
Attr.Year_f = num2str(Year_f);
Attr.Size   = size(V{1});
ATTR{1}     = Attr;
ATTR{2}     = ATTR{1};
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Disturbed days
M    = repmat(X(:,1),1,5)';
M    = M(:);
Y    = repmat(X(:,2),1,5)';
Y    = Y(:);

DAY   = X(:,13:17)';
DAY   = DAY(:);
D     = ones(length(DAY),1);
RANK  = repmat([1:5]',size(X,1),1);

I     = find( round(10*(DAY-floor(DAY))) == 3);
D(I)  = -1; % Not really disturbed

disturbed = [Y,M,floor(DAY),D];
I         = find(Y <= Year_f);
disturbed = disturbed(I,:);
rank      = RANK(I);

No  = day_number(1932,1,1);
Nf  = day_number(Year_f,12,31);
Nd  = day_number(disturbed(:,1:3)) - No + 1;

temp1          = zeros(Nf-No+1,1);
temp2          = zeros(Nf-No+1,1);
temp1(Nd)      = disturbed(:,4);
temp2(Nd)      = rank;
disturbed_days = [temp1,temp2];

V{3}           = disturbed_days(:,1);
V{4}           = disturbed_days(:,2);

Attr.Year_o = num2str(Year_o);
Attr.Year_f = num2str(Year_f);
Attr.Size   = size(V{3});
ATTR{3}     = Attr;
ATTR{4}     = Attr;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
