function ATTR = ModelWeb_info(Attr_in)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
inSys='GSM';
outSys='GSE';
ATTR{1}        = ts_attr;
ATTR{1}.Year_o = Attr_in{1}.Year_o;
ATTR{1}.Year_f = Attr_in{1}.Year_f;
ATTR{1}.PPD    = 24;
ATTR{1}.Size   = Attr_in{1}.Size;
ATTR{1}.Name   = 'Matrix to transform vector from GSM to GSE';
ATTR{1}.Source = ...
    ['Transform library (CXFORM-0.6) obtained '...
     'http://nssdc.gsfc.nasa.gov/space/model/models_home_o.html'];
ATTR{1}.Acknowledgement=...
    ['Transform computed using the cxform library downloaded from NSSDC ModelWeb page http://modelweb.gsfc.nasa.gov/models_home_o.html CXFORM was originally written by Ed Santiago (LANL) and was modified & is maintained by Ryan Boller (NASA/GSFC), Ryan.A.Boller@nasa.gov.  Acknowledgement Format for models obtained throught NSSDC web page: "If you use models, or results of model calculations, obtained from these pages in a publication, please acknowledge NSSDC as: "The model (or model results) was (were) obtained from the web pages of NASA''s National Space Science Data Center."'];

ATTR{1}.Note = ['Transform matrix for first value in time series is the' ...
		' average of the transform matrices on January 1, 1963 at' ...
		' UT=00:00:00 and UT=01:00:00. Second transform matrix is' ...
		' the average of UT=01:00 and UT=02:00, etc.  Values' ...
		' differ from those calculated at UT=00:29:59,' ...
		' UT=01:29:59, etc by is less than one percent.'...
		' Use http://sscweb.gsfc.nasa.gov/cgi-bin/sscweb/' ...
		'CoordCalculator.cgi to spot check data.'] ;

ATTR{1}.README  = ...
sprintf(['If the cartesian values of vector V in %s are '...
	 '[Vx,Vy,Vz] = [V(1),V(2),V(3)], '...
         'then V in the %s system (== Vt) is '... 
	 'Vt(1) = T(1)*V(1)+T(4)*V(2)+T(7)*V(3); ' ...
	 'Vt(2) = T(2)*V(1)+T(5)*V(2)+T(8)*V(3);, ' ...
	 'Vt(3) = T(3)*V(1)+T(6)*V(2)+T(9)*V(3);'...
	 ' if T is 1x9 and '...
	 'Vt(:,1)  = T(:,1).*V(:,1)+T(:,4).*V(:,2)+T(:,7).*V(:,3);'...
	 'Vt(:,2)  = T(:,2).*V(:,1)+T(:,5).*V(:,2)+T(:,8).*V(:.3);'...
	 'Vt(:,3)  = T(:,3).*V(:,1)+T(:,6).*V(:,2)+T(:,9).*V(:,3);'...
	 ' if T has two or more rows.'],inSys,outSys);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
