function ATTR = NSGC_Kp_Ap_info(Attr_in,version)

  
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Common attributes
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%  
Attr             = ts_attr;
Attr.Version     = num2str(version);
Attr.CreatedWith = ['NGDC.m'];

Attr.Acknowledgement = 'See README';

Attr.README = ...
    ['ftp://ftp.ngdc.noaa.gov/STP/GEOMAGNETIC_DATA/INDICES/KP_AP/read-me.txt'...
     ' ftp://ftp.ngdc.noaa.gov/STP/GEOMAGNETIC_DATA/INDICES/KP_AP/kp_ap.fmt'];

Attr.Source = ...
    'ftp://ftp.ngdc.noaa.gov/STP/GEOMAGNETIC_DATA/INDICES/KP_AP/';

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%  

NAMES{1} = 'BARTELS SOLAR ROTATION NUMBER';
NOTE{1}  = ['BARTELS SOLAR ROTATION NUMBER is a sequence of 27-day intervals'...
	    'counted continuously from February 8, 1832.'];

NAMES{2} = 'NUMBER OF DAY within the Bartels 27-day cycle.';
NOTE{2}  = '';

NAMES{3} = 'Kp index';
NOTE{3}  = ['Kp is the PLANETARY 3-HOUR RANGE INDEX.'];

NAMES{4} = 'SUM of the eight Kp indices for the day expressed to the neaest third of a unit.';
NOTE{4} = '';

NAMES{5} = 'ap index';
NOTE{5}  = ['ap is the PLANETARY EQUIVALENT AMPLITUDE.'];

NAMES{6} = 'Ap index';
NOTE{6} = ['Ap, or the PLANETARY EQUIVALENT DAILY AMPLITUDE, is the arithmetic'...
          ' mean of the day''s eight ap values.'];

NAMES{7} = 'Cp index';
NOTE{7}  = ['Cp or the PLANETARY DAILY CHARACTER FIGURE, is a qualitative' ...
	    ' estimate of overall level of magnetic activity for the day' ...
	     ' determined from the sum of the eight ap amplitudes.  Cp ranges,'...
	     ' in steps of one-tenth, from 0 (quiet) to 2.5 (highly disturbed).'];

NAMES{8} = 'C9'; 	    
NOTE{8} = 'C9 is a conversion of the 0-to-2.5 range of the Cp index to one digit between 0 and 9';

NAMES{9} = 'INTERNATIONAL SUNSPOT NUMBER';
NOTE{9} = 'Records contain the Zurich number through December 31, 1980, and the International Brus-sels number thereafter.';

NAMES{10} = 'OTTAWA 10.7-CM SOLAR RADIO FLUX ADJUSTED';
NOTE{10} = ['ADJUSTED TO 1 AU--measured at 1700 UT daily and expressed in units of 10 to the -22 Watts/meter sq/hertz.  Observations began on February 14, 1947. From that date through December 31, 1973, the fluxes given here don''t reflect the revisions Ottawa made in 1966.'];

NAMES{11} = 'FLUX QUALIFIER';
NOTE{11} = '"0" indicates flux required no adjustment; "1" indicates flux required adjustment for burst in progress at time of measurement; "2" indicates a flux approximated by either interpolation or extrapolation; and "3" indicates no observation.';

for i = 1:length(Attr_in)  

  Attr.Year_o   = Attr_in{i}.Year_o;
  Attr.Year_f   = Attr_in{i}.Year_f;
  Attr.Size     = Attr_in{i}.Size;

  if (i == 8)
    Attr.Unit = '10^-22 Watts/meter sq/hertz';
  else
    Attr.Unit = '';
  end

  if (i == 3) | (i == 5)
    Attr.PPD      = 24;
    Attr.TimeUnit = 'hour';
    Attr.Name = [NAMES{i}, ' (NGDC 1-hour)'];
  else
    Attr.PPD      = 1;
    Attr.TimeUnit = 'day';
    Attr.Name = [NAMES{i}, ' (NGDC 1-day)'];
  end

  Attr.Note = NOTE{i};
  ATTR{i} = Attr;
  
end
