function [Files_good] = Nagoya_mm210_extract(DATA_DIR,parse_files)
%DMI_1_HOUR_EXTRACT
%
%   Files = DMI_1_HOUR_EXTRACT(Data_dir)
%
%   Transform and concatanate all 1-hour .wdc files into .dat files (with no
%   strings) using a Perl script.  Load this .dat file and save as a .mat
%   file.
%
%   ASCII file abc_hr.dat has columns YEAR MONTH DAY ELEMENT QD TB DATA AVE
%
%   abc is the magnetometer 3-letter code.
%   ELEMENT is 0,1,2,3,4,5 for D,H,X,Y,Z,F
%   QD = 1 for international quiet and 2 for disturbed.
%   TB is the tabular base.
%   DATA is 24 columns corresponding to 24 hours in 
%
%   .mat file abc_hr.mat has matrix variable named abc_hr with contents of
%   .dat file abc_hr.dat.
%
%   Files = DMI_1_HOUR_EXTRACT(Data_dir,parse_files) If parse_files = 0, do
%   not call Perl script and use existing .dat files to create .mat files.
%
%
  
if (nargin < 2)
  parse_files = 1;
end
  
TSDS_GLOBALS;  

TEMPDIR = [TSDS_DATA_TEMP,'/Nagoya_mm210'];

if (parse_files == 1)
% Call the Perl program.
com = sprintf(['cd %s ; rm -rf %s/* ; mkdir -p %s ; '...
	       '%s %s/Nagoya_mm210_extract.pl %s'],...
	      DATA_DIR,...
	      TEMPDIR,...
	      TEMPDIR,...
	      TSDS_PERL,...
	      TSDS_PERLFILES,...
	      TEMPDIR);

if (parse_files)
  system(com);
end
end

D = readdir(TEMPDIR);

if (isempty(D))
  error('Nagoya_mm210_extract.m: No files to process. Try setting parse_files=1')
end

% Octave's readdir function changed sometime after 2.1.50 (output is cell).
% instead of char array.  This will break on Octave versions after 2.1.50
% that output a cell and if strvcat function cannot handle cell arrays.

if (iscell(D))
  if (is_octave)
    Dm = [];
    for i = 1:length(D)
      Dm = strvcat(Dm,D{i});
    end
    D = Dm;
  else
    D = strvcat(D);
  end
end

Files = D;


if (parse_files == 0) % Do not recreate .mat files, only get names

  k = 1;
  for i = 1:size(Files,1)

    if ~isempty(findstr(Files(i,:),'.mat')) % If file has extension .mat

      mag = Files(i,1:3);
      var = Files(i,1:9);
      
      Files_good{k} = sprintf('%s/%s',TEMPDIR,Files(i,:));
      Attr{k}.Name = sprintf('%s',mag);    

      k = k + 1;
    
    end
  end
  
end      

if (parse_files == 1)

k = 1;
for i = 1:size(Files,1)

  if ~isempty(findstr(Files(i,:),'.dat')) % If file has extension .dat

    mag = Files(i,1:3);
    var = Files(i,1:9);
    
    try % to load .dat file created by wdcMIN2dat.pl.

      % Load transformed .dat files.
      com = sprintf('load %s',sprintf('%s/%s',TEMPDIR,Files(i,:)));
      fprintf('Evaluating command: %s\n',com);
      eval(com);
      
      % Save all data for given mag in an individual .mat binary file.
      if (is_octave)
	com = sprintf('save -mat-binary %s/%s.mat %s ; clear %s;',...
		      TEMPDIR,var,var,var);
      else
	com = sprintf('save %s/%s.mat %s ; clear %s ;',...
		      TEMPDIR,var,var,var);
      end
      
      fprintf('Evaluating command: %s\n',com);
      eval(com);
      
      datfile = sprintf('%s/%s',TEMPDIR,Files(i,:));
      rm(datfile);      
      fprintf('Removed %s\n',datfile);
      
      Files_good{k} = sprintf('%s/%s.mat',TEMPDIR,var);
      Attr{k}.Name = sprintf('%s',mag);
      k = k + 1;
      
      
    catch % catch, report failure, and continue
      
      fprintf('Problems with load command: %s\n',lasterr);
      fprintf('Continuing.\n');
      
    end

  end % if strmatch
  
end

end % if parse_files
