function [V,ATTR] = Nagoya_mm210_extract2(Files)

TSDS_GLOBALS;  

TEMPDIR = [TSDS_DATA_TEMP,'/Nagoya_mm210/tmp'];

system(sprintf('rm -rf %s ; mkdir -p %s',TEMPDIR,TEMPDIR)); 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Load .mat files created by _extract.m, convert FLAGS, fill
% missing hours.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
Ntseries = 1;

EL_NAME  = ['D','H','X','Y','Z','F'];

for k = 1:length(Files)

  fprintf('\nLoading %s\n',Files{k});
  
  vname = deblank(Files{k});
  vname = vname(end-12:end-4);
  mag = vname(1:3);

  com   = sprintf('load(''%s''); X=%s ; clear %s ; ',...
		  deblank(Files{k}),vname,vname);
  fprintf('Evaluating %s\n',com);
  eval(com);

  if (strmatch('adl',mag))
    I = find(X(:,1) ~= 28); % 05/18/1992 data has year = 28.  Ignore data
                            % on this day.
    X = X(I,:);			    
  end
  
  I = find((X(:,1) >= 90) & (X(:,1) <= 99));
  X(I,1) = 1900+X(I,1);
  I = find((X(:,1) >= 0) & (X(:,1) < 90));
  X(I,1) = 2000+X(I,1);
  % Year 2090 problem ...
  
  Year_o = min(X(:,1));
  Year_f = max(X(:,1));

  if (Year_f >= 2090)
    error('Year_f too large'); 
  end

  fprintf('Yo = %6d, Yf = %6d \n',Year_o,Year_f);
  
  fprintf('Checking time series length\n');

  fprintf('Sorting data\n');

  % Put data in correct order if not already
  Hn      = 24*day_number(X(:,1:3)) + X(:,4); 
  Hn      = Hn - 24*day_number([Year_o,1,1]);
  [Hn,Is] = sort(Hn); 
  X       = X(Is,:); clear Is;

  fprintf('Creating time vector\n');

  fprintf('Computing minute number\n');
  Mn = cumsum([60*(Hn') + 1 ; ones(59,length(Hn))]); clear Hn;
  
  EL  = X(1,5); 
  AVE = X(:,66);    % Will be ignored.

  fprintf('Reshaping\n');
  X  = reshape(X(:,6:65)', 60*size(X,1),1 ); % 60 data points per day
  X  = reflag(X,999999,NaN);  
  
  fprintf('%s component, ',EL_NAME(EL+1));

  % Number of days possible
  Nd = number_days(Year_o,Year_f); 
  Nm = 1440*Nd; % Number of minutes possible
  
  if (Nm == length(X))
    fprintf(['\nNumber of minutes of data same as number minutes in \n'...
	     'interval. No filling necessary.\n']);
    Var = X ; clear Mn X; 	
  else
    warnstr = sprintf('Number of data points is %d (%d possible)',...
		      length(X),Nm);
    warnstr = sprintf('%s. Filling missing minutes with %d',...
		      warnstr,NaN);
    fprintf('%s\n',warnstr);

    fprintf('Inserting data.\n');    
    Var     = repmat(NaN,Nm,1);
    Var(Mn) = X; clear Mn Is X; 	
    
  end % if Nm
  
  Attr.Size   = size(Var);
  Attr.Name   = sprintf('%s %s',upper(mag),EL_NAME(EL+1));
  Attr.Year_o = num2str(Year_o);
  Attr.Year_f = num2str(Year_f);
  
  % Sanity check that the number of intervals matches what is expected.
  if (~isempty(Var))
    L_diff  = Nm - length(Var);
    if (L_diff ~= 0)
      error('Time series length is incorrect');
    end
  end

  V{Ntseries}    = sprintf('%s/temp%d.mat',TEMPDIR,Ntseries);
  ATTR{Ntseries} = Attr;
      
  if (is_octave == 1)
    com = sprintf('save %s Var Attr',V{Ntseries});
  else
    com = sprintf('save -V6 %s Var Attr',V{Ntseries});
  end
  
  fprintf('%s\n',com);      
  eval(com);

  clear Var;
  
  Ntseries = Ntseries + 1;

end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
