function [V,ATTR] = SourceAcronym_extract(DATADIR)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Get global variables and path setting
TSDS_GLOBALS;

Year_f = 2003;
  
com = sprintf('cd %s ; %s %s/SourceAcronym_extract.pl %s',...
	      DATADIR,TSDS_PERL,TSDS_PERLFILES,TSDS_DATA_TEMP);
system(com);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% First data file
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
fname    = [TSDS_DATA_TEMP,'/SourceAcronym_extract.dat'];
temp_X   = load(fname);
time     = temp_X(:,1:3);
temp_X   = temp_X(:,4:5);

% Put data in standard format
% First three columns of ap_7dUSAF are Year, Month, Day
doy_o    = doy(time(1,:));             % Find doy of first day of data
doy_f    = doy(time(end,:));           % Find doy of last day of data
Year_o   = time(1,1);
Year_f   = time(end,1);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Add flags so data starts on beginning of first year when data is available
% and ends on last day of last year when data is available.
if (doy_o ~= 1)
  pad_o = NaN*ones(doy_o-1,size(temp_X,2));
else
  pad_o = [];
end

Nd_f = number_days(time(1,1));
if (doy_f ~= Nd_f)
  pad_f = NaN*ones(Nd_f-doy_f,size(temp_X,2));  
else
  pad_f = [];
end

temp_X  = [pad_o; temp_X ; pad_f]; 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

X       = temp_X(:,1);  % Actual X
X_pred  = temp_X(:,2);  % 1-7 day lead time forecasted X

% Change flag from -99999 to NaN
X      = reflag(X,-TSDS_FLAG,NaN);
X_pred = reflag(X_pred,-TSDS_FLAG,NaN);

if ( number_days(Year_o,Year_f) ~= size(X,1) )
  error('Wrong number of data points. Aborting.');
end

Attr.Year_o = num2str(Year_o);
Attr.Year_f = num2str(Year_f);
Attr.Size   = size(X);

V{1}     = X;  clear X;
ATTR{1}  = Attr;

Attr.Year_o = num2str(Year_o);
Attr.Year_f = num2str(Year_f);
Attr.Size   = size(X_pred);

V{2}     = X;  clear X;
ATTR{2}  = Attr;
