function [V,ATTR] = WSA_Vsw_extract(DATA_DIR)
% Transform WSA data files to uniform format.

TSDS_GLOBALS;

eval(sprintf('load %s/mwopred4.dat',DATA_DIR));  

JD    = mwopred4(:,1);              % JD information
t     = mwopred4(:,2:4);            % Time information
T     = [t(:,3) t(:,1) t(:,2)];     % Columns are Yr Mo Day

% Determine fraction of Julian Day
dJD    = JD-floor(JD(1)); 

% Add 0.5 since fractional part of JD is zero at noon universal time.
dJD   = mod(dJD+0.5,1);  % Fraction of UT day after first data point 
temp  = 24.0*dJD; % Fraction UT hour
HR    = round(temp-0.5); % Round to nearest half hour interval
T     = [T HR];

Vel     = mwopred4(:,6);          % Solar wind velocity is last column

fprintf('First Data Point at Year = %d Month = %d Day = %d %f\n',...
	T(1,1),T(1,2),T(1,3),Vel(1));
fprintf('Last Data Point at Year = %d Month = %d Day = %d %f\n',...
	T(end,1),T(end,2),T(end,3),Vel(end));

% Put V data on uniform time grid at 1-hour resolution
[Xu,Xu,Tu] = time_union2([T Vel],[T Vel],99999,'hour');
Year_o     = (T(1,1));
Year_f     = (T(end,1));

V = reflag(Xu,99999,NaN);

ATTR.Size    = size(V);
ATTR.Year_o  = num2str(Year_o);
ATTR.Year_f  = num2str(Year_f);
