%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This code has been tested using Octave 2.1.50 and Matlab 6.5 on RHEL3.0
%
% Generates a four-column data file of hourly values of H from four
% magnetometers used in the computation of Dst.
%  
% Data are taken from .txt files in the directory
% TSDS_DATA-Full/measurements/original_data/SPIDR/...
% Ground_Magnetometer/Dst_Magnetometers/txtfiles
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% R.S. Weigel 05/06/2004

clear;

% Get global variables and path setting
TSDS_GLOBALS;

SAVE_LOCATION = [TSDS_DATA_LOCAL_WRITE,'measurements/uniform_time_series/'];

end_year  = 2002;
SPIDR_DIR = [TSDS_DATA_LOCAL_WRITE,...
     'measurements/original_data/SPIDR/Ground_Magnetometer/Dst_Magnetometers/'];

cwd       = pwd;
cd(SPIDR_DIR);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% These next two steps will take ~10 minutes on a 2 GHz Pentium IV. Comment out
% if you don't need to re-create the .dat and .mat files.      
system([TSDS_PERL_PATH,' ',CISM_DX_ROOT,'perlfiles/spidr2dat.pl']);
dat2mat;   
      
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        load([SPIDR_DIR,'HER_H.mat']);
HER_H = unique(HER_H,'rows'); % Remove any and sort wrt time duplicates
        load([SPIDR_DIR,'HON_H.mat']);
HON_H = unique(HON_H,'rows');
        load([SPIDR_DIR,'KAK_H.mat']);
KAK_H = unique(KAK_H,'rows');
        load([SPIDR_DIR,'SJG_H.mat']);
SJG_H = unique(SJG_H,'rows');
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

rm('*.dat');
rm('*.mat');

cd(cwd);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

Xc = time_union({HON_H,HER_H,KAK_H,SJG_H},9999,'hour');
for i = 1:length(Xc)
  X(:,i) = reflag(Xc{i},9999,FLAG);
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
fid=fopen(sprintf('%sdatafiles/SPIDR_HON_HER_KAK_SJG_H_1_hour_1902_%d.dat',...
		  SAVE_LOCATION,end_year),'w');
fprintf(fid,'%d %d %d %d\n',X');
fclose(fid);

com=sprintf('save %smatfiles/SPIDR_HON_HER_KAK_SJG_H_1_hour_1902_%d.mat X',...
	    SAVE_LOCATION,end_year);
eval(com);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

I = 1 + 24*number_days(1902,1962);
X = X(I:end,:); % Keep only days from 1963 till end of 2002

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
com=sprintf('save %smatfiles/SPIDR_HON_HER_KAK_SJG_H_1_hour_1963_%d.mat X',...
	    SAVE_LOCATION,end_year);
eval(com);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

