function ts_sds(sd_id,A,SDS)
%TS_HDF_SDS Inserts a SDS into a HDF file
%
%   TS_HDF_SDS is called by TS_HDF
%
%   

% R.S. Weigel 11/12/2004

  TSDS_GLOBALS;
  
  if (is_octave == 1)
    fprintf80(['ts_hdf_sds    :'...
	       'Need HDFSD function in Matlab to perform this operation.\n']);
  end

  if (isempty(SDS.Size))
    fprintf80(['ts_hdf_sds    : '...
	       'Time series does not have an attribute named Size.'...
	       'Cannot proceed']);
    error('Aborting.');
  end

  if (isempty(A))
    A = TSDS_FLAG*ones(SDS.Size);
  end

  if (ndims(A)>2)
    error('A must have dimension less than 3');
  end

  A = A'; 
  
  ds_name   = SDS.Name;
  A         = single(A);
  ds_type   = 'float32';
  ds_rank   = ndims(A);
  ds_dims   = fliplr(size(A));
  
  sds_id    = hdfsd('create',sd_id,ds_name,ds_type,ds_rank,ds_dims);
  status(1) = hdfsd('setcompress',sds_id,'deflate','deflate_level',5);
  
  ds_start  = zeros(1:ndims(A)); % Start at the beginning
  ds_stride = [];                % Write every element. 
  ds_edges  = fliplr(size(A));   % Reverse the dimensions.

  status(4) = hdfsd('setdatastrs',...
		    sds_id,SDS.Name,SDS.Unit,SDS.Format,SDS.CoordinateSystem);
  status(3) = hdfsd('writedata',sds_id ,ds_start, ds_stride, ds_edges, A);
  
  attr_name  = 'Size';
  attr_value = num2str(SDS.Size);
  status     = hdfsd('setattr',sds_id,attr_name,attr_value);

  attr_name  = 'Data Type';
  attr_value = SDS.DataType;
  status     = hdfsd('setattr',sds_id,attr_name,attr_value);

  attr_name  = 'Format';
  attr_value = SDS.Format;
  status     = hdfsd('setattr',sds_id,attr_name,attr_value);

  attr_name  = 'Name';
  attr_value = SDS.Name;
  status     = hdfsd('setattr',sds_id,attr_name,attr_value);

  attr_name  = 'Label';
  attr_value = SDS.Label; 
  status     = hdfsd('setattr',sds_id,attr_name,attr_value);

  attr_name  = 'Version';
  attr_value = SDS.Version;
  status     = hdfsd('setattr',sds_id,attr_name,attr_value);
  
  attr_name  = 'Note';
  attr_value = SDS.Note;
  status     = hdfsd('setattr',sds_id,attr_name,attr_value);

  attr_name  = 'Coordinate System';
  attr_value = SDS.CoordinateSystem;
  status     = hdfsd('setattr',sds_id,attr_name,attr_value);

  attr_name  = 'Geographic Latitude, Longitude in degrees';
  attr_value = SDS.GeographicLatLong;
  status     = hdfsd('setattr',sds_id,attr_name,attr_value);

  attr_name  = 'Geomagnetic Latitude , Longitude (degrees), MLTMN (hours)';
  attr_value = SDS.GeomagneticLatLong;
  status     = hdfsd('setattr',sds_id,attr_name,attr_value);

  attr_name  = 'Unit';
  attr_value = SDS.Unit;
  status     = hdfsd('setattr',sds_id,attr_name,attr_value);

  attr_name  = 'Time Unit';
  attr_value = SDS.TimeUnit;
  status     = hdfsd('setattr',sds_id,attr_name,attr_value);

  attr_name  = 'Points Per Day';
  attr_value = SDS.PPD;
  status     = hdfsd('setattr',sds_id,attr_name,attr_value);

  attr_name  = 'Time spacing of data';
  attr_value = SDS.Dt;
  status     = hdfsd('setattr',sds_id,attr_name,attr_value);

  attr_name  = 'Year_o';
  attr_value = SDS.Year_o;
  status(2)  = hdfsd('setattr',sds_id,attr_name,attr_value);

  attr_name  = 'Year_f';
  attr_value = SDS.Year_f;
  status(2)  = hdfsd('setattr',sds_id,attr_name,attr_value);

  attr_name  = 'Flag for missing or bad data';
  attr_value = num2str(SDS.FLAG);
  status(2)  = hdfsd('setattr',sds_id,attr_name,attr_value);

  attr_name  = 'Data Source';
  attr_value = SDS.Source;
  status     = hdfsd('setattr',sds_id,attr_name,attr_value);

  attr_name  = 'Acknowledgement';
  attr_value = SDS.Acknowledgement;
  status     = hdfsd('setattr',sds_id,attr_name,attr_value);

  attr_name  = 'Warning';
  attr_value = SDS.Warning;
  status     = hdfsd('setattr',sds_id,attr_name,attr_value);

  attr_name  = 'README';
  attr_value = SDS.README;
  status     = hdfsd('setattr',sds_id,attr_name,attr_value);

  status(9) = hdfsd('endaccess',sds_id);  

  if (max(status) < 0)
    I = find(status == -1);
    fprintf('HDF file problem starting at status(%d).\n',status(I(1)));
  end
