function ts_mat(Attr_cell,Var_cell,basename,clean,regen_db)
%TS_MAT
%
%  TS_MAT(Attr_cell,Var_cell)
%  
%  TS_MAT(Attr_cell,Var_cell,basename) Creates .mat files with tag
%  basename.
%
%  TS_MAT(Attr_cell,Var,basename,basepart,clean) If clean = 'clean',
%  removes all files matching *basename*mat before processing.  basename and
%  basepart can be [];
%
%

TSDS_GLOBALS;

if (strmatch(TSDS_USERNAME,'base'))
  fprintf80(['ts_mat       : Before exchanging data, change the string' ...
	     ' TSDS_USERNAME in TSDS_GLOBALS.m to your last name']);
end

if (~iscell(Attr_cell))
  Attr_cell = {Attr_cell};
end
if (~iscell(Var_cell))
  Var_cell = {Var_cell};
end

if (nargin < 3)
  basename = '';
else
  if ~isempty(basename)
    basename = ['_',basename];
  end
end

if (is_unix==1)
  slash = '/';
else
  slash = '\\';
  slash = slash(1);
end

if (nargin > 3)
  if (strmatch(clean,'clean','exact'))
    fprintf80(sprintf(['ts_mat       : Removing all files matching '...
                       '%s%s*%s.*\n'],...
		      TSDS_DATA_LOCAL_WRITE,slash,basename));
    fprintf80(sprintf(['ts_mat       : Removing all files matching '...
	               '%s%s*%s-*\n'],...
		      TSDS_DATA_LOCAL_WRITE,slash,basename));

    if (is_unix == 1)
      rm(sprintf('%s%s*%s-*',TSDS_DATA_LOCAL_WRITE,slash,basename));
      rm(sprintf('%s%s*%s.*',TSDS_DATA_LOCAL_WRITE,slash,basename));
    else
      rm(sprintf('"%s%s*%s-*"',TSDS_DATA_LOCAL_WRITE,slash,basename));
      rm(sprintf('"%s%s*%s.*"',TSDS_DATA_LOCAL_WRITE,slash,basename));
    end
  end
end

fname = sprintf('%s%sTSDS_%s%s.mat',...
		TSDS_DATA_LOCAL_WRITE,slash,TSDS_USERNAME,basename);

if exist(fname) | exist([fname,'.gz'])
  
  fn          = 0; % See if .1, .2, etc files exist.
  fname_check = fname;
  
  while ( exist(fname_check) | exist([fname_check,'.gz']))
    
    if (fn > 0)
      fprintf80(...
	  sprintf(['ts_mat       : Found existing file with basename '...
		   '%s.%d.\n'],basename,fn));
    else
      fprintf80(...
	  sprintf(['ts_mat       : Found existing file with basename '...
		   '%s.\n'],basename));
    end

    fn = fn+1;

    fname_check    = sprintf('%s/TSDS_%s%s.%d.mat',...
			     TSDS_DATA_LOCAL_WRITE,TSDS_USERNAME,...
			     basename,fn);
  end

  if (fn > 1)  
    fname    = sprintf('%s/TSDS_%s%s.%d.mat',...
		       TSDS_DATA_LOCAL_WRITE,TSDS_USERNAME,basename,fn-1);
  end

  if exist([fname,'.gz'])
    gunzip([fname,'.gz'],TSDS_GZIP)
  end

  if (is_octave == 0)
    W  = whos('-file',fname);
    Nb = cat(1,W.bytes); % Sometimes W.bytes returns two
			 % arrays.  Why?
    Nb = Nb(end);        % In the case where it does return two
			 % arrays the second one is correct.
  else
    W  = stat(fname);
    Nb = W.size;
  end


  if Nb > TSDS_MAX_FILESIZE; % If existing file is larger than allowed

    fprintf80(sprintf(['ts_mat       : Existing file %s'...
		       ' is too large to append.  Starting new file.'],fname));

    fname = sprintf('%s%sTSDS_%s%s.%d.mat',...
		    TSDS_DATA_LOCAL_WRITE,slash,TSDS_USERNAME,basename,fn);


  else

    fprintf80(sprintf('ts_mat       : Appending.'));
    FILE = load(fname);    
    N = length(FILE.Attr_cell);
    Var_cell = [FILE.Var_cell,Var_cell];
    Attr_cell = [FILE.Attr_cell,Attr_cell];
%keyboard
%    for i = 1:length(FILE.Var_cell)
%      Var_cell{N+i}  = FILE.Var_cell{i};
%      Attr_cell{N+i} = FILE.Attr_cell{i};
%    end
    clear FILE;
%    gzip(fname,TSDS_GZIP)
  end

end


if (is_octave == 0)
  ml_ver=version;
  if (str2num(ml_ver(1))>6)
   SAVE_OPT = '-V6';
  else
   SAVE_OPT = '';
  end
else
  SAVE_OPT = '';
end

fprintf80(sprintf('ts_mat       : Writing %s',fname));
if (is_unix == 1)
  eval( sprintf('save %s %s Var_cell Attr_cell',SAVE_OPT,fname) );
else
  if ~isempty(SAVE_OPT)
    sprintf('save ''%s'' ''%s'' Var_cell Attr_cell',SAVE_OPT,fname) 
  else
    save(fname,'Var_cell','Attr_cell');
  end
end

%if (~exist('fn'))
  fprintf80(sprintf('ts_mat       : gzipping %s',fname));
  gzip(fname,TSDS_GZIP);
%end

fname = [fname(1:end-4),'-metadataonly.mat'];

if (is_unix == 1)
  eval( sprintf('save %s %s  Attr_cell',SAVE_OPT,fname) );
else
  if ~isempty(SAVE_OPT)
    sprintf('save ''%s'' ''%s'' Attr_cell',SAVE_OPT,fname) 
  else
    save(fname,'Attr_cell');
  end
end

fprintf80(sprintf('ts_mat       : Wrote %s',fname));
