function success = ts_download(fname)
%TS_DOWNLOAD Use wget to download a requested file.
%
%   TS_DOWNLOAD is called by TS_GET.
%
%   success = TS_DOWNLOAD(fname), where success = 0 or 1.
%           
%   See also TS_GET.

% R.S. Weigel 11/17/2004
  
TSDS_GLOBALS;

if (is_unix == 1)
  slash = '/';
end
if (is_unix == 0)
  slash = '\\'; % Octave does not like a lone forward slash.
end

success = 0;

fname = [fname,'.gz'];

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Is the file in a local directory?
islocal = exist(fname,'file');

% If not in local directory, try to download.
if (islocal == 0)
  shouldi = 'y';

  if (strmatch(shouldi,'y'))

    com_sep = ';'; % Command separator in unix script is semicolon
    if (is_unix==0),com_sep = '&';,end; % and & for DOS

    if (is_unix == 1)
      com_str1 = sprintf('cd %s %s ',TSDS_DATA_LOCAL_WRITE,com_sep);
      if exist(TSDS_WGET)
	com_str2 = sprintf('%s %s ',TSDS_WGET,TSDS_WGET_ARGS);
      elseif exist(TSDS_CURL)
	com_str2 = sprintf('%s %s %s ',TSDS_CURL,TSDS_CURL_ARGS,fname);      
      end	  
      com_str3 = sprintf('%s/%s ',TSDS_DATA_HTTP,fname);
    else 
      com_str1 = sprintf('cd "%s" %s ',TSDS_DATA_LOCAL_WRITE,com_sep);
      if exist(TSDS_WGET)
	com_str2 = sprintf('"%s" %s ',TSDS_WGET,TSDS_WGET_ARGS);
      elseif exist(TSDS_CURL)
	com_str2 = sprintf('"%s" %s %s ',TSDS_CURL,TSDS_CURL_ARGS,fname);
      end	  
      com_str3 = sprintf('"%s/%s" ',TSDS_DATA_HTTP,fname);
    end

    linestr = repmat('_',1,80);
    fprintf80(...
	sprintf(...
	    'ts_download   : Calling the system with commands: %s %s %s',...
	    com_str1,com_str2,com_str3));
    fprintf80(...
	sprintf('ts_download   : Output of system command to follow'));
    pause(2); % Pause so user can see what is about to happen
    fprintf('%s\n',linestr);
    system([com_str1,com_str2,com_str3]);
    fprintf('%s\n',linestr);

    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % Need to put a check here for file size in case of failure
    % before full file is downloaded.  The following will return
    % success in that case.
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    if (exist([TSDS_DATA_LOCAL_WRITE,slash(1),fname],'file') == 0) & ...
       (exist([TSDS_DATA_LOCAL_WRITE,slash(1),fname,'.gz'],'file') == 0)
      success = 0;
    else
      success = 1;
    end
  end
end
