function ts_export(DATA,fname)
%TS_EXPORT Write data to a file
%
%   TS_EXPORT(DATA,Fname), where DATA is a variable and string Fname can
%   have extension txt, mat (Matlab V6 native), or dx (OpenDX native).
%
%   Example: DATA = [1:10]; ts_export(DATA,'DATAfile.txt') ; pwd ; ls -l *.txt
%            writes a text file with the numbers 1-10. The command "pwd"
%            lists the working directory.
%
%   Example: DATA = ts_list; ts_export(DATA,'DATAfile.txt')
%            writes the full list of TSDS time series names to a plain
%            text file.
%
%   Example: t = (pi/8)*[0:80]';
%            DATA.positions = [t.*cos(t),t.*sin(t),t];
%            DATA.data = [cos(t)-t.*sin(t),sin(t)+t.*cos(t),ones(length(t),1)];
%            ts_export(DATA,'ParametricCurve.dx') create the data file
%            used in the CISM_DX example network ParametricCurve.net.
%            
%   See also TS_EXPORT_DEMO, TSDS.

fprintf80(sprintf('ts_export     : Writing data to file %s',fname));
fprintf80(sprintf('              : in directory %s',pwd));

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% mat
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if strmatch(fname(end-2:end),'txt')
  com = sprintf('save -text %s DATA',fname)
  eval(com)
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% mat
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if strmatch(fname(end-2:end),'mat')
  if exist('LOADPATH') % If Octave
    com = sprintf('save %s DATA',fname);
    eval(com);
  else
    tmpVER = ver;
    if (str2num(tmpVer(1).Version) < 7)
      eval(sprintf('save %s TS_DBs',fname));
    else
      eval(sprintf('save -V6 %s TS_DBs',fname));    
    end
  end
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% dx
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if strmatch(fname(end-1:end),'dx')
  if isfield(DATA,'positions') & isfield(DATA,'data')
    % Ok.
  else
    error(['ts_export: For .dx output, DATA must be a structure with '...
	   'elements named "positions" and "data"']);
  end
  
  fid = fopen(fname,'wt');

  str1 = sprintf(['object 1 class array type float rank 1 shape 3 '...
		  'items %d data follows\n'],size(DATA.positions,1));
  str2 = sprintf('object 2 class gridconnections counts %d\n',...
		 size(DATA.positions,1));
  str3 = sprintf(['object 3 class array type float rank 1 shape 3 items '...
		  '%d data follows\n'],size(DATA.data,1));
  str4 = sprintf('attribute "dep" string "positions"\n');
  str5 = sprintf(['object "regular positions regular connections" '...
		  'class field\n']);
  str6 = sprintf('component "positions" value 1\n');
  str7 = sprintf('component "connections" value 2\n');
  str8 = sprintf('component "data" value 3\n');
  str9 = sprintf('#\n');
  str10 = sprintf('end\n');

  fprintf(fid,str1);
  fprintf(fid,'%f %f %f\n',DATA.positions');
  fprintf(fid,str2);
  fprintf(fid,str3);
  fprintf(fid,'%f %f %f\n',DATA.data');
  fprintf(fid,str4);
  fprintf(fid,str5);
  fprintf(fid,str6);
  fprintf(fid,str7);
  fprintf(fid,str8);
  fprintf(fid,str9);
  fprintf(fid,str10);
  
  fclose(fid);
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

fprintf80(sprintf('              : Done.',pwd));